#delimit ;

set linesize 250;


/* MAIN ANALYSES OF WHO RUNS FROM POOL, AND WHO WINS PRIMARY AND GENERAL ELECTIONS */


/* DEMOCRATS */

use ../pools_data/merged_data_33_dems, clear;
keep if Contested == 1;
rename Year     year;
rename Ran      ran;
rename District dist;
rename Ideology ideology;
drop type;
gen     type = "G" if Special == 0;
replace type = "S" if Special == 1;
merge m:1 state dist year type using ../other_data/cong_incumbency;
drop if _merge == 2;
drop _merge;
merge m:1 state dist year type using ../other_data/pres_vote_to_use;
drop if _merge == 2;
drop _merge;
gen  party = "D";

gen byte open_seat = (inc_D == 0 & inc_R == 0);
gen byte safe   = (d_pres_vote_pct >  57.5)                           if d_pres_vote_pct != .;
gen byte compet = (d_pres_vote_pct >= 42.5 & d_pres_vote_pct <= 57.5) if d_pres_vote_pct != .;

egen x = count(year), by(Unique_ID Legislator);
sort Unique_ID Legislator;
drop if x > 1 & Legislator == Legislator[_n-1];
drop x;

replace Won_Primary = 0 if Won_Primary == .;
replace Won_General = 0 if Won_General == .;

egen xmin = min(Won_Primary), by(Unique_ID);
egen xmax = max(Won_Primary), by(Unique_ID);
gen variation_Won_Primary = 1 if xmin < xmax;
drop xmin xmax;

egen xmin = min(Won_General), by(Unique_ID);
egen xmax = max(Won_General), by(Unique_ID);
gen variation_Won_General = 1 if xmin < xmax;
drop xmin xmax;

* egen x = pctile(ideology), p(1);
* drop if ideology < x;
* drop x;
* egen x = pctile(ideology), p(99);
* drop if ideology > x;
* drop x;


/* LINEAR PROBABILITY MODEL */

areg ran ideology,                   absorb(Unique_ID) cluster(state);
local b_r_D_1 =  _b[ideology];
local s_r_D_1 = _se[ideology];
local n_r_D_1 = e(N);

areg ran ideology if open_seat == 1, absorb(Unique_ID) cluster(state);
local b_r_D_2 =  _b[ideology];
local s_r_D_2 = _se[ideology];
local n_r_D_2 = e(N);

areg ran ideology if safe == 1,      absorb(Unique_ID) cluster(state);
local b_r_D_3 =  _b[ideology];
local s_r_D_3 = _se[ideology];
local n_r_D_3 = e(N);

areg ran ideology if compet == 1,    absorb(Unique_ID) cluster(state);
local b_r_D_4 =  _b[ideology];
local s_r_D_4 = _se[ideology];
local n_r_D_4 = e(N);


areg Won_Primary ideology if variation_Won_Primary == 1,                  absorb(Unique_ID) cluster(state);
local b_p_D_1 =  _b[ideology];
local s_p_D_1 = _se[ideology];
local n_p_D_1 = e(N);

areg Won_Primary ideology if variation_Won_Primary == 1 & open_seat == 1, absorb(Unique_ID) cluster(state);
local b_p_D_2 =  _b[ideology];
local s_p_D_2 = _se[ideology];
local n_p_D_2 = e(N);

areg Won_Primary ideology if variation_Won_Primary == 1 & safe == 1,      absorb(Unique_ID) cluster(state);
local b_p_D_3 =  _b[ideology];
local s_p_D_3 = _se[ideology];
local n_p_D_3 = e(N);

areg Won_Primary ideology if variation_Won_Primary == 1 & compet == 1,    absorb(Unique_ID) cluster(state);
local b_p_D_4 =  _b[ideology];
local s_p_D_4 = _se[ideology];
local n_p_D_4 = e(N);


areg Won_General ideology if variation_Won_General == 1,                  absorb(Unique_ID) cluster(state);
local b_g_D_1 =  _b[ideology];
local s_g_D_1 = _se[ideology];
local n_g_D_1 = e(N);

areg Won_General ideology if variation_Won_General == 1 & open_seat == 1, absorb(Unique_ID) cluster(state);
local b_g_D_2 =  _b[ideology];
local s_g_D_2 = _se[ideology];
local n_g_D_2 = e(N);

areg Won_General ideology if variation_Won_General == 1 & safe == 1,      absorb(Unique_ID) cluster(state);
local b_g_D_3 =  _b[ideology];
local s_g_D_3 = _se[ideology];
local n_g_D_3 = e(N);

areg Won_General ideology if variation_Won_General == 1 & compet == 1,    absorb(Unique_ID) cluster(state);
local b_g_D_4 =  _b[ideology];
local s_g_D_4 = _se[ideology];
local n_g_D_4 = e(N);


/* CONDITIONAL LOGIT MODEL */

clogit ran ideology,                   group(Unique_ID) cluster(state);
local b_r_D_5 =  _b[ideology];
local s_r_D_5 = _se[ideology];
local n_r_D_5 = e(N);

clogit ran ideology if open_seat == 1, group(Unique_ID) cluster(state);
local b_r_D_6 =  _b[ideology];
local s_r_D_6 = _se[ideology];
local n_r_D_6 = e(N);

clogit ran ideology if safe == 1,      group(Unique_ID) cluster(state);
local b_r_D_7 =  _b[ideology];
local s_r_D_7 = _se[ideology];
local n_r_D_7 = e(N);

clogit ran ideology if compet == 1,    group(Unique_ID) cluster(state);
local b_r_D_8 =  _b[ideology];
local s_r_D_8 = _se[ideology];
local n_r_D_8 = e(N);


clogit Won_Primary ideology if variation_Won_Primary == 1,                  group(Unique_ID) cluster(state);
local b_p_D_5 =  _b[ideology];
local s_p_D_5 = _se[ideology];
local n_p_D_5 = e(N);

clogit Won_Primary ideology if variation_Won_Primary == 1 & open_seat == 1, group(Unique_ID) cluster(state);
local b_p_D_6 =  _b[ideology];
local s_p_D_6 = _se[ideology];
local n_p_D_6 = e(N);

clogit Won_Primary ideology if variation_Won_Primary == 1 & safe == 1,      group(Unique_ID) cluster(state);
local b_p_D_7 =  _b[ideology];
local s_p_D_7 = _se[ideology];
local n_p_D_7 = e(N);

clogit Won_Primary ideology if variation_Won_Primary == 1 & compet == 1,    group(Unique_ID) cluster(state);
local b_p_D_8 =  _b[ideology];
local s_p_D_8 = _se[ideology];
local n_p_D_8 = e(N);


clogit Won_General ideology if variation_Won_General == 1,                  group(Unique_ID) cluster(state);
local b_g_D_5 =  _b[ideology];
local s_g_D_5 = _se[ideology];
local n_g_D_5 = e(N);

clogit Won_General ideology if variation_Won_General == 1 & open_seat == 1, group(Unique_ID) cluster(state);
local b_g_D_6 =  _b[ideology];
local s_g_D_6 = _se[ideology];
local n_g_D_6 = e(N);

clogit Won_General ideology if variation_Won_General == 1 & safe == 1,      group(Unique_ID) cluster(state);
local b_g_D_7 =  _b[ideology];
local s_g_D_7 = _se[ideology];
local n_g_D_7 = e(N);

clogit Won_General ideology if variation_Won_General == 1 & compet == 1,    group(Unique_ID) cluster(state);
local b_g_D_8 =  _b[ideology];
local s_g_D_8 = _se[ideology];
local n_g_D_8 = e(N);


/* REPUBLICANS */

use ../pools_data/merged_data_33_reps, clear;
keep if Contested == 1;
rename Year     year;
rename Ran      ran;
rename District dist;
rename Ideology ideology;
drop type;
gen     type = "G" if Special == 0;
replace type = "S" if Special == 1;
merge m:1 state dist year type using ../other_data/cong_incumbency;
drop if _merge == 2;
drop _merge;
merge m:1 state dist year type using ../other_data/pres_vote_to_use;
drop if _merge == 2;
drop _merge;
gen  party = "R";

gen byte open_seat = (inc_D == 0 & inc_R == 0);
gen r_pres_vote_pct = 100 - d_pres_vote_pct;
gen byte safe   = (r_pres_vote_pct >  57.5)                           if r_pres_vote_pct != .;
gen byte compet = (r_pres_vote_pct >= 42.5 & r_pres_vote_pct <= 57.5) if r_pres_vote_pct != .;

egen x = count(year), by(Unique_ID Legislator);
sort Unique_ID Legislator;
drop if x > 1 & Legislator == Legislator[_n-1];
drop x;

replace Won_Primary = 0 if Won_Primary == .;
replace Won_General = 0 if Won_General == .;

egen xmin = min(Won_Primary), by(Unique_ID);
egen xmax = max(Won_Primary), by(Unique_ID);
gen variation_Won_Primary = 1 if xmin < xmax;
drop xmin xmax;

egen xmin = min(Won_General), by(Unique_ID);
egen xmax = max(Won_General), by(Unique_ID);
gen variation_Won_General = 1 if xmin < xmax;
drop xmin xmax;

* egen x = pctile(ideology), p(1);
* drop if ideology < x;
* drop x;
* egen x = pctile(ideology), p(99);
* drop if ideology > x;
* drop x;

areg ran ideology,                   absorb(Unique_ID) cluster(state);
local b_r_R_1 =  _b[ideology];
local s_r_R_1 = _se[ideology];
local n_r_R_1 = e(N);

areg ran ideology if open_seat == 1, absorb(Unique_ID) cluster(state);
local b_r_R_2 =  _b[ideology];
local s_r_R_2 = _se[ideology]; 
local n_r_R_2 = e(N);

areg ran ideology if safe == 1,      absorb(Unique_ID) cluster(state);
local b_r_R_3 =  _b[ideology];
local s_r_R_3 = _se[ideology];
local n_r_R_3 = e(N);

areg ran ideology if compet == 1,    absorb(Unique_ID) cluster(state);
local b_r_R_4 =  _b[ideology];
local s_r_R_4 = _se[ideology];
local n_r_R_4 = e(N);


areg Won_Primary ideology if variation_Won_Primary == 1,                  absorb(Unique_ID) cluster(state);
local b_p_R_1 =  _b[ideology];
local s_p_R_1 = _se[ideology];
local n_p_R_1 = e(N);

areg Won_Primary ideology if variation_Won_Primary == 1 & open_seat == 1, absorb(Unique_ID) cluster(state);
local b_p_R_2 =  _b[ideology];
local s_p_R_2 = _se[ideology];
local n_p_R_2 = e(N);

areg Won_Primary ideology if variation_Won_Primary == 1 & safe == 1,      absorb(Unique_ID) cluster(state);
local b_p_R_3 =  _b[ideology];
local s_p_R_3 = _se[ideology];
local n_p_R_3 = e(N);

areg Won_Primary ideology if variation_Won_Primary == 1 & compet == 1,    absorb(Unique_ID) cluster(state);
local b_p_R_4 =  _b[ideology];
local s_p_R_4 = _se[ideology];
local n_p_R_4 = e(N);


areg Won_General ideology if variation_Won_General == 1,                  absorb(Unique_ID) cluster(state);
local b_g_R_1 =  _b[ideology];
local s_g_R_1 = _se[ideology];
local n_g_R_1 = e(N);

areg Won_General ideology if variation_Won_General == 1 & open_seat == 1, absorb(Unique_ID) cluster(state);
local b_g_R_2 =  _b[ideology];
local s_g_R_2 = _se[ideology];
local n_g_R_2 = e(N);

areg Won_General ideology if variation_Won_General == 1 & safe == 1,      absorb(Unique_ID) cluster(state);
local b_g_R_3 =  _b[ideology];
local s_g_R_3 = _se[ideology];
local n_g_R_3 = e(N);

areg Won_General ideology if variation_Won_General == 1 & compet == 1,    absorb(Unique_ID) cluster(state);
local b_g_R_4 =  _b[ideology];
local s_g_R_4 = _se[ideology];
local n_g_R_4 = e(N);


clogit ran ideology,                   group(Unique_ID) cluster(state);
local b_r_R_5 =  _b[ideology];
local s_r_R_5 = _se[ideology];
local n_r_R_5 = e(N);

clogit ran ideology if open_seat == 1, group(Unique_ID) cluster(state);
local b_r_R_6 =  _b[ideology];
local s_r_R_6 = _se[ideology]; 
local n_r_R_6 = e(N);

clogit ran ideology if safe == 1,      group(Unique_ID) cluster(state);
local b_r_R_7 =  _b[ideology];
local s_r_R_7 = _se[ideology];
local n_r_R_7 = e(N);

clogit ran ideology if compet == 1,    group(Unique_ID) cluster(state);
local b_r_R_8 =  _b[ideology];
local s_r_R_8 = _se[ideology];
local n_r_R_8 = e(N);


clogit Won_Primary ideology if variation_Won_Primary == 1,                  group(Unique_ID) cluster(state);
local b_p_R_5 =  _b[ideology];
local s_p_R_5 = _se[ideology];
local n_p_R_5 = e(N);

clogit Won_Primary ideology if variation_Won_Primary == 1 & open_seat == 1, group(Unique_ID) cluster(state);
local b_p_R_6 =  _b[ideology];
local s_p_R_6 = _se[ideology];
local n_p_R_6 = e(N);

clogit Won_Primary ideology if variation_Won_Primary == 1 & safe == 1,      group(Unique_ID) cluster(state);
local b_p_R_7 =  _b[ideology];
local s_p_R_7 = _se[ideology];
local n_p_R_7 = e(N);

clogit Won_Primary ideology if variation_Won_Primary == 1 & compet == 1,    group(Unique_ID) cluster(state);
local b_p_R_8 =  _b[ideology];
local s_p_R_8 = _se[ideology];
local n_p_R_8 = e(N);


clogit Won_General ideology if variation_Won_General == 1,                  group(Unique_ID) cluster(state);
local b_g_R_5 =  _b[ideology];
local s_g_R_5 = _se[ideology];
local n_g_R_5 = e(N);

clogit Won_General ideology if variation_Won_General == 1 & open_seat == 1, group(Unique_ID) cluster(state);
local b_g_R_6 =  _b[ideology];
local s_g_R_6 = _se[ideology];
local n_g_R_6 = e(N);

clogit Won_General ideology if variation_Won_General == 1 & safe == 1,      group(Unique_ID) cluster(state);
local b_g_R_7 =  _b[ideology];
local s_g_R_7 = _se[ideology];
local n_g_R_7 = e(N);

clogit Won_General ideology if variation_Won_General == 1 & compet == 1,    group(Unique_ID) cluster(state);
local b_g_R_8 =  _b[ideology];
local s_g_R_8 = _se[ideology];
local n_g_R_8 = e(N);


/************************************************************/
/********** LATEX TABLE OF MAIN REGRESSION RESULTS **********/
/************************************************************/

quietly {;

  capture log close;
  log using ../output/tables/tbl_appendix_lpm_run_33.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf Within-Pool Comparisons: Predicting Probability of Running from Ideology} ";
  noisily display "\label{tbl_appendix_lpm_run_33} ";
  noisily display "\begin{tabular}{lcccccc} ";
  noisily display "\toprule\toprule ";
  noisily display "& \multicolumn{3}{c}{Democrats} & \multicolumn{3}{c}{~Republicans} \\ [.05in] "; 
  noisily display "Sample                 & Coeff.  & Std. Error  &  \# Obs.  & ~~Coeff.  &  Std. Error  &  \# Obs.  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "All pools              & " %4.3f `b_r_D_1' " & (" %4.3f `s_r_D_1' ") & [" %3.0f `n_r_D_1' "] & ~~" %4.3f `b_r_R_1' " & (" %4.3f `s_r_R_1' ") & [" %3.0f `n_r_R_1' "] \\ [.01in] "; 
  noisily display "Open seats             & " %4.3f `b_r_D_2' " & (" %4.3f `s_r_D_2' ") & [" %3.0f `n_r_D_2' "] & ~~" %4.3f `b_r_R_2' " & (" %4.3f `s_r_R_2' ") & [" %3.0f `n_r_R_2' "] \\ [.01in] "; 
  noisily display "Safe districts         & " %4.3f `b_r_D_3' " & (" %4.3f `s_r_D_3' ") & [" %3.0f `n_r_D_3' "] & ~~" %4.3f `b_r_R_3' " & (" %4.3f `s_r_R_3' ") & [" %3.0f `n_r_R_3' "] \\ [.01in] ";
  noisily display "Competitive districts  & " %4.3f `b_r_D_4' " & (" %4.3f `s_r_D_4' ") & [" %3.0f `n_r_D_4' "] & ~~" %4.3f `b_r_R_4' " & (" %4.3f `s_r_R_4' ") & [" %3.0f `n_r_R_4' "] \\ [.01in] "; 
  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};



quietly {;

  capture log close;
  log using ../output/tables/tbl_appendix_lpm_win_prim_genl_33.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf Within-Pool Comparisons: Predicting Probability of Winning Primary or General Election from Ideology} ";
  noisily display "\label{tbl_appendix_lpm_win_prim_genl_33} ";
  noisily display "\begin{tabular}{lcccccc} ";
  noisily display "\toprule\toprule ";
  noisily display "& \multicolumn{3}{c}{Democrats} & \multicolumn{3}{c}{~Republicans} \\ [.05in] "; 
  noisily display "Sample                 & Coeff.  & Std. Error  &  \# Obs.  & ~~Coeff.  &  Std. Error  &  \# Obs.  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "\multicolumn{7}{l}{\textit{Primary Election Winners vs. Others in Pool}} \\ [0.01in] ";
  noisily display "All pools              & " %4.3f `b_p_D_1' " & (" %4.3f `s_p_D_1' ") & [" %3.0f `n_p_D_1' "] & ~~" %4.3f `b_p_R_1' " & (" %4.3f `s_p_R_1' ") & [" %3.0f `n_p_R_1' "] \\ [.01in] "; 
  noisily display "Safe districts         & " %4.3f `b_p_D_3' " & (" %4.3f `s_p_D_3' ") & [" %3.0f `n_p_D_3' "] & ~~" %4.3f `b_p_R_3' " & (" %4.3f `s_p_R_3' ") & [" %3.0f `n_p_R_3' "] \\ [.01in] ";
  noisily display "Competitive districts  & " %4.3f `b_p_D_4' " & (" %4.3f `s_p_D_4' ") & [" %3.0f `n_p_D_4' "] & ~~" %4.3f `b_p_R_4' " & (" %4.3f `s_p_R_4' ") & [" %3.0f `n_p_R_4' "] \\ [.01in] "; 
  noisily display "\midrule ";
  noisily display "\multicolumn{7}{l}{\textit{General Election Winners vs. Others in Pool}} \\ [0.01in] ";
  noisily display "All pools              & " %4.3f `b_g_D_1' " & (" %4.3f `s_g_D_1' ") & [" %3.0f `n_g_D_1' "] & ~~" %4.3f `b_g_R_1' " & (" %4.3f `s_g_R_1' ") & [" %3.0f `n_g_R_1' "] \\ [.01in] "; 
  noisily display "Safe districts         & " %4.3f `b_g_D_3' " & (" %4.3f `s_g_D_3' ") & [" %3.0f `n_g_D_3' "] & ~~" %4.3f `b_g_R_3' " & (" %4.3f `s_g_R_3' ") & [" %3.0f `n_g_R_3' "] \\ [.01in] ";
  noisily display "Competitive districts  & " %4.3f `b_g_D_4' " & (" %4.3f `s_g_D_4' ") & [" %3.0f `n_g_D_4' "] & ~~" %4.3f `b_g_R_4' " & (" %4.3f `s_g_R_4' ") & [" %3.0f `n_g_R_4' "] \\ [.01in] "; 
  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};


quietly {;

  capture log close;
  log using ../output/tables/tbl_appendix_logit_run_33.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf Within-Pool Comparisons: Logistic Regression of Running on Ideology} ";
  noisily display "\label{tbl_appendix_logit_run_33} ";
  noisily display "\begin{tabular}{lcccccc} ";
  noisily display "\toprule\toprule ";
  noisily display "& \multicolumn{3}{c}{Democrats} & \multicolumn{3}{c}{~Republicans} \\ [.05in] "; 
  noisily display "Sample                 & Coeff.  & Std. Error  &  \# Obs.  & ~~Coeff.  &  Std. Error  &  \# Obs.  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "All pools              & " %4.3f `b_r_D_5' " & (" %4.3f `s_r_D_5' ") & [" %3.0f `n_r_D_5' "] & ~~" %4.3f `b_r_R_5' " & (" %4.3f `s_r_R_5' ") & [" %3.0f `n_r_R_5' "] \\ [.01in] "; 
  noisily display "Open seats             & " %4.3f `b_r_D_6' " & (" %4.3f `s_r_D_6' ") & [" %3.0f `n_r_D_6' "] & ~~" %4.3f `b_r_R_6' " & (" %4.3f `s_r_R_6' ") & [" %3.0f `n_r_R_6' "] \\ [.01in] "; 
  noisily display "Safe districts         & " %4.3f `b_r_D_7' " & (" %4.3f `s_r_D_7' ") & [" %3.0f `n_r_D_7' "] & ~~" %4.3f `b_r_R_7' " & (" %4.3f `s_r_R_7' ") & [" %3.0f `n_r_R_7' "] \\ [.01in] ";
  noisily display "Competitive districts  & " %4.3f `b_r_D_8' " & (" %4.3f `s_r_D_8' ") & [" %3.0f `n_r_D_8' "] & ~~" %4.3f `b_r_R_8' " & (" %4.3f `s_r_R_8' ") & [" %3.0f `n_r_R_8' "] \\ [.01in] "; 
  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};



quietly {;

  capture log close;
  log using ../output/tables/tbl_appendix_logit_win_prim_genl_33.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf Within-Pool Comparisons: Logistic Regression of Winning Primary or General Election on Ideology} ";
  noisily display "\label{tbl_appendix_logit_win_prim_genl_33} ";
  noisily display "\begin{tabular}{lcccccc} ";
  noisily display "\toprule\toprule ";
  noisily display "& \multicolumn{3}{c}{Democrats} & \multicolumn{3}{c}{~Republicans} \\ [.05in] "; 
  noisily display "Sample                 & Coeff.  & Std. Error  &  \# Obs.  & ~~Coeff.  &  Std. Error  &  \# Obs.  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "\multicolumn{7}{l}{\textit{Primary Election Winners vs. Others in Pool}} \\ [0.01in] ";
  noisily display "All pools              & " %4.3f `b_p_D_5' " & (" %4.3f `s_p_D_5' ") & [" %3.0f `n_p_D_5' "] & ~~" %4.3f `b_p_R_5' " & (" %4.3f `s_p_R_5' ") & [" %3.0f `n_p_R_5' "] \\ [.01in] "; 
  noisily display "Safe districts         & " %4.3f `b_p_D_7' " & (" %4.3f `s_p_D_7' ") & [" %3.0f `n_p_D_7' "] & ~~" %4.3f `b_p_R_7' " & (" %4.3f `s_p_R_7' ") & [" %3.0f `n_p_R_7' "] \\ [.01in] ";
  noisily display "Competitive districts  & " %4.3f `b_p_D_8' " & (" %4.3f `s_p_D_8' ") & [" %3.0f `n_p_D_8' "] & ~~" %4.3f `b_p_R_8' " & (" %4.3f `s_p_R_8' ") & [" %3.0f `n_p_R_8' "] \\ [.01in] "; 
  noisily display "\midrule ";
  noisily display "\multicolumn{7}{l}{\textit{General Election Winners vs. Others in Pool}} \\ [0.01in] ";
  noisily display "All pools              & " %4.3f `b_g_D_5' " & (" %4.3f `s_g_D_5' ") & [" %3.0f `n_g_D_5' "] & ~~" %4.3f `b_g_R_5' " & (" %4.3f `s_g_R_5' ") & [" %3.0f `n_g_R_5' "] \\ [.01in] "; 
  noisily display "Safe districts         & " %4.3f `b_g_D_7' " & (" %4.3f `s_g_D_7' ") & [" %3.0f `n_g_D_7' "] & ~~" %4.3f `b_g_R_7' " & (" %4.3f `s_g_R_7' ") & [" %3.0f `n_g_R_7' "] \\ [.01in] ";
  noisily display "Competitive districts  & " %4.3f `b_g_D_8' " & (" %4.3f `s_g_D_8' ") & [" %3.0f `n_g_D_8' "] & ~~" %4.3f `b_g_R_8' " & (" %4.3f `s_g_R_8' ") & [" %3.0f `n_g_R_8' "] \\ [.01in] "; 
  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};