#delimit ;

set linesize 250;


/* MERGE POOLS WITH BONICA DATA */

use "../other_data/dime_cong_elections_current.dta", clear;
drop if Incum_Chall == "I";
drop if seat == "federal:senate";
rename cycle year;
rename recipient_cfscore cf_score;
keep if year >= 1996 & year <= 2016;
keep bonica_rid Name year cf_score num_distinct_donors district party;
gsort bonica_rid year -num_distinct_donors;
drop if bonica_rid == bonica_rid[_n-1] & year == year[_n-1];
save tmp1, replace;

use ../pools_data/merged_data_33_dems, clear;
append using ../pools_data/merged_data_33_reps;
rename Year     year;
rename Ran      ran;
rename District dist;
rename Ideology ideology;
merge m:1 state dist year type using ../other_data/cong_incumbency;
drop if _merge == 2;
drop _merge;
merge m:1 state dist year type using ../other_data/pres_vote_to_use;
drop if _merge == 2;
drop _merge;
gen party = Legislator_Party;
rename bonicaid bonica_rid;
drop if bonica_rid == "";
merge m:1 bonica_rid year using tmp1;
save tmp1, replace;

replace state = substr(district, 1, 2) if state == "";
replace dist = real(substr(district, 3, .)) if dist == .;

keep if party == "D" | party == "R";

gsort state dist year party -Unique_ID;
replace Unique_ID = Unique_ID[_n-1] if Unique_ID == "" & state == state[_n-1] & dist == dist[_n-1] & year == year[_n-1] & party == party[_n-1];

replace type = "G" if type == "" & cf_score != .;

drop _merge;
merge m:1 state dist year type using ../other_data/pres_vote_to_use, update;

drop state_leg;
gen state_leg = ideology != .;

drop if cf_score == .; 
drop if Unique_ID == "";
drop if num_distinct_donors < 30;

replace d_pres_vote_pct = d_pres_vote_pct/100;

sum year if cf_score != . & d_pres_vote_pct != . & state_leg != .;
local m = r(min);
gen t = year - `m';

xi:  reg cf_score state_leg     d_pres_vote_pct i.year if party == "D", cluster(state);
local b_leg_D_1 =  _b[state_leg];
local s_leg_D_1 = _se[state_leg];
local b_dvs_D_1 =  _b[d_pres_vote_pct];
local s_dvs_D_1 = _se[d_pres_vote_pct];
local n_D_1 = e(N);

xi:  reg cf_score state_leg     d_pres_vote_pct i.year if party == "R", cluster(state);
local b_leg_R_1 =  _b[state_leg];
local s_leg_R_1 = _se[state_leg];
local b_dvs_R_1 =  _b[d_pres_vote_pct];
local s_dvs_R_1 = _se[d_pres_vote_pct];
local n_R_1 = e(N);

xi: areg cf_score state_leg                            if party == "D", a(Unique_ID) cluster(state);
local b_leg_D_2 =  _b[state_leg];
local s_leg_D_2 = _se[state_leg];
local n_D_2 = e(N);

xi: areg cf_score state_leg                            if party == "R", a(Unique_ID) cluster(state);
local b_leg_R_2 =  _b[state_leg];
local s_leg_R_2 = _se[state_leg];
local n_R_2 = e(N);


/* THESE ARE FOR FOOTNOTE IN PAPER TO CHECK DIFFERENTIAL TRENDS FOR STATE LEGISLATORS AND NON-LEGISLATORS (TRENDS ARE NOT SIGNIFICANTLY DIFFERENT) */

xi:  reg cf_score i.state_leg*t d_pres_vote_pct i.year if party == "D", cluster(state);
xi:  reg cf_score i.state_leg*t d_pres_vote_pct i.year if party == "R", cluster(state);

quietly {;

  capture log close;
  log using ../output/tables/tbl_state_legs_vs_others_2.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf Ideology of state legislators compared to non-state legislators, CFScores.} ";
  noisily display "\label{tbl_state_legs_vs_others_2} ";
  noisily display "\begin{tabular}{lcccc} ";
  noisily display "\toprule\toprule ";
  noisily display "& Democrats & Republicans & Democrats & Republicans \\ ";
  noisily display "\midrule ";
  noisily display "State Legislator        &  " %5.3f `b_leg_D_1' "  &  " %5.3f `b_leg_R_1' "  &  " %5.3f `b_leg_D_2' "  &  " %5.3f `b_leg_R_2' "  \\ "; 
  noisily display "                        & (" %5.3f `s_leg_D_1' ") & (" %5.3f `s_leg_R_1' ") & (" %5.3f `s_leg_D_2' ") & (" %5.3f `s_leg_R_2' ") \\ [.01in] "; 
  noisily display "Dem Pres Vote Share     &  " %5.3f `b_dvs_D_1' "  &  " %5.3f `b_dvs_R_1' "  &   --   &   --   \\ "; 
  noisily display "                        & (" %5.3f `s_dvs_D_1' ") & (" %5.3f `s_dvs_R_1' ") &        &        \\ [.01in] "; 
  noisily display "Observations            &  " %3.0f `n_D_1'     "  &  " %3.0f `n_R_1'     "  &  " %3.0f `n_D_2'     "  &  " %3.0f `n_R_2'     "  \\ "; 
  noisily display "\midrule ";
  noisily display "Pool Fixed Effects      & No & No & Yes & Yes \\ ";
  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};

erase tmp1.dta;
