#delimit ;

set linesize 250;


/* ANALYSES OF IDEOLOGICAL DIFFERENCES BETWEEN RUNNERS AND NON-RUNNERS */

/* SUMMARY STATISTICS OF WHO RUNS AND WHO DOES NOT */

use          ../pools_data/merged_data_33_dems_prev_cycle, clear;
append using ../pools_data/merged_data_33_reps_prev_cycle;
rename Year year;
rename District dist;
rename Legislator_Party party;
rename Legislator name;
rename Ideology ideology;
gen     type = "G" if Special == 0;
replace type = "S" if Special == 1;
merge m:1 state year dist type party name using ../other_data/cong_primaries_1996_2016;
gen byte ran = (w_p != .);
drop if _merge == 2;
drop _merge;
merge m:1 state dist year type using ../other_data/cong_incumbency;
drop if _merge == 2;
drop _merge;
merge m:1 state dist year type using ../other_data/pres_vote_to_use;
drop if _merge == 2;
drop _merge;
gen legislator_id = state + " " + name;

gsort state name party year -ran;
drop if state == state[_n-1] & name == name[_n-1] & party == party[_n-1] & year == year[_n-1];

sum ideology if party == "D" & ran == 1;
local mean_ran_D = r(mean);
local N_ran_D = r(N);

sum ideology if party == "D" & ran == 0;
local mean_not_D = r(mean);
local N_not_D = r(N);

sum ideology if party == "R" & ran == 1;
local mean_ran_R = r(mean);
local N_ran_R = r(N);

sum ideology if party == "R" & ran == 0;
local mean_not_R = r(mean);
local N_not_R = r(N);

ttest ideology if party == "D", by(ran);
reg  ideology ran if party == "D", cluster(legislator_id);
areg ideology ran if party == "D", a(state) cluster(legislator_id);
ttest ideology if party == "R", by(ran);
reg  ideology ran if party == "R", cluster(legislator_id);
areg ideology ran if party == "R", a(state) cluster(legislator_id);



/******************************************************************************/
/********** LATEX TABLE OF SUMMARY STATS FOR RUNNERS AND NON-RUNNERS **********/
/******************************************************************************/

quietly {;

  capture log close;
  log using ../output/tables/tbl_summary_runners_nonrunners_33_expanded_pool.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf NP-Score of State Legislators Who Run vs. Those Who Do Not -- Expanded Pool Including Retired State Legislators} ";
  noisily display "\label{tbl_summary_runners_nonrunners_33_expanded_pool} ";
  noisily display "\begin{tabular}{lcrcr} ";
  noisily display "\toprule\toprule ";
  noisily display "& \multicolumn{2}{c}{Democrats} & \multicolumn{2}{c}{Republicans} \\ [.05in] "; 
  noisily display "            & Mean.       &          & Mean       &          \\ ";
  noisily display "Item        & NP-Score    & \# Obs.  & NP-Score   & \# Obs.  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "Ran for Congress  & " %6.3f `mean_ran_D' " & " %6.0fc `N_ran_D' " & " %6.3f `mean_ran_R' " & " %6.0fc `N_ran_R' " \\ [.01in] "; 
  noisily display "Did Not Run       & " %6.3f `mean_not_D' " & " %6.0fc `N_not_D' " & " %6.3f `mean_not_R' " & " %6.0fc `N_not_R' " \\ [.01in] "; 
  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};



/* MAIN ANALYSES OF WHO RUNS FROM POOL, AND WHO WINS PRIMARY AND GENERAL ELECTIONS */

/* DEMOCRATS */

use          ../pools_data/merged_data_33_dems_prev_cycle, clear;
rename Year year;
rename District dist;
rename Legislator_Party party;
gen name = Legislator;
rename Ideology ideology;
gen     type = "G" if Special == 0;
replace type = "S" if Special == 1;
merge m:1 state year dist type party name using ../other_data/cong_primaries_1996_2016;
gen byte ran = (w_p != .);
drop if _merge == 2;
drop _merge;
merge m:1 state dist year type using ../other_data/cong_incumbency;
drop if _merge == 2;
drop _merge;
merge m:1 state dist year type using ../other_data/pres_vote_to_use;
drop if _merge == 2;
drop _merge;
gen legislator_id = state + " " + name;

egen x = sum(w_p != .), by(Unique_ID);
* drop n;
egen n = count(year), by(Unique_ID);
keep if x >= 1;
keep if n >= 2;
drop x n;

gen byte open_seat = (inc_D == 0 & inc_R == 0);
* gen byte safe   = (d_pres_vote_pct >  57.5)                           if d_pres_vote_pct != .;
* gen byte compet = (d_pres_vote_pct >= 42.5 & d_pres_vote_pct <= 57.5) if d_pres_vote_pct != .;
  gen byte safe   = (d_pres_vote_pct >  55.0)                           if d_pres_vote_pct != .;
  gen byte compet = (d_pres_vote_pct >= 45.0 & d_pres_vote_pct <= 55.0) if d_pres_vote_pct != .;

egen x = count(year), by(Unique_ID Legislator);
sort Unique_ID Legislator;
drop if x > 1 & Legislator == Legislator[_n-1];
drop x;

gen byte Won_Primary = 1 if w_p == 1;
replace  Won_Primary = 0 if Won_Primary == .;
gen byte Won_General = 1 if w_g == 1;
replace  Won_General = 0 if Won_General == .;

egen xmin = min(Won_Primary), by(Unique_ID);
egen xmax = max(Won_Primary), by(Unique_ID);
gen variation_Won_Primary = 1 if xmin < xmax;
drop xmin xmax;

egen xmin = min(Won_General), by(Unique_ID);
egen xmax = max(Won_General), by(Unique_ID);
gen variation_Won_General = 1 if xmin < xmax;
drop xmin xmax;

* egen x = pctile(ideology), p(1);
* drop if ideology < x;
* drop x;
* egen x = pctile(ideology), p(99);
* drop if ideology > x;
* drop x;

egen pool_size = count(ideology), by(Unique_ID);
egen pool_sd   = sd(ideology), by(Unique_ID);

save tmp1, replace;


collapse (mean) pool_size pool_sd, by(Unique_ID);

sum pool_size, detail;
local median_pool_size = r(p50);

sum pool_sd, detail;
local median_pool_sd = r(p50);


use tmp1, clear;


areg ideology ran,                   absorb(Unique_ID) cluster(state);
local b_r_D_1 =  _b[ran];
local s_r_D_1 = _se[ran];
local n_r_D_1 = e(N);

areg ideology ran if open_seat == 1, absorb(Unique_ID) cluster(state);
local b_r_D_2 =  _b[ran];
local s_r_D_2 = _se[ran];
local n_r_D_2 = e(N);

areg ideology ran if safe == 1,      absorb(Unique_ID) cluster(state);
local b_r_D_3 =  _b[ran];
local s_r_D_3 = _se[ran];
local n_r_D_3 = e(N);

areg ideology ran if compet == 1,    absorb(Unique_ID) cluster(state);
local b_r_D_4 =  _b[ran];
local s_r_D_4 = _se[ran];
local n_r_D_4 = e(N);


gen large = (pool_size > `median_pool_size') if pool_size != .;

xi: areg ideology i.ran*large, absorb(Unique_ID) cluster(state);

areg ideology ran if large == 1, absorb(Unique_ID) cluster(state);
local b_r_D_5 =  _b[ran];
local s_r_D_5 = _se[ran];
local n_r_D_5 = e(N);

areg ideology ran if large == 0, absorb(Unique_ID) cluster(state);
local b_r_D_6 =  _b[ran];
local s_r_D_6 = _se[ran];
local n_r_D_6 = e(N);


gen hi_sd = (pool_sd > `median_pool_sd') if pool_sd != .;

xi: areg ideology i.ran*hi_sd, absorb(Unique_ID) cluster(state);

areg ideology ran if hi_sd == 1, absorb(Unique_ID) cluster(state);
local b_r_D_7 =  _b[ran];
local s_r_D_7 = _se[ran];
local n_r_D_7 = e(N);

areg ideology ran if hi_sd == 0, absorb(Unique_ID) cluster(state);
local b_r_D_8 =  _b[ran];
local s_r_D_8 = _se[ran];
local n_r_D_8 = e(N);


areg ideology Won_Primary if variation_Won_Primary == 1,                  absorb(Unique_ID) cluster(state);
local b_p_D_1 =  _b[Won_Primary];
local s_p_D_1 = _se[Won_Primary];
local n_p_D_1 = e(N);

areg ideology Won_Primary if variation_Won_Primary == 1 & open_seat == 1, absorb(Unique_ID) cluster(state);
local b_p_D_2 =  _b[Won_Primary];
local s_p_D_2 = _se[Won_Primary];
local n_p_D_2 = e(N);

areg ideology Won_Primary if variation_Won_Primary == 1 & safe == 1,      absorb(Unique_ID) cluster(state);
local b_p_D_3 =  _b[Won_Primary];
local s_p_D_3 = _se[Won_Primary];
local n_p_D_3 = e(N);

areg ideology Won_Primary if variation_Won_Primary == 1 & compet == 1,    absorb(Unique_ID) cluster(state);
local b_p_D_4 =  _b[Won_Primary];
local s_p_D_4 = _se[Won_Primary];
local n_p_D_4 = e(N);


areg ideology Won_General if variation_Won_General == 1,                  absorb(Unique_ID) cluster(state);
local b_g_D_1 =  _b[Won_General];
local s_g_D_1 = _se[Won_General];
local n_g_D_1 = e(N);

areg ideology Won_General if variation_Won_General == 1 & open_seat == 1, absorb(Unique_ID) cluster(state);
local b_g_D_2 =  _b[Won_General];
local s_g_D_2 = _se[Won_General];
local n_g_D_2 = e(N);

areg ideology Won_General if variation_Won_General == 1 & safe == 1,      absorb(Unique_ID) cluster(state);
local b_g_D_3 =  _b[Won_General];
local s_g_D_3 = _se[Won_General];
local n_g_D_3 = e(N);

areg ideology Won_General if variation_Won_General == 1 & compet == 1,    absorb(Unique_ID) cluster(state);
local b_g_D_4 =  _b[Won_General];
local s_g_D_4 = _se[Won_General];
local n_g_D_4 = e(N);



/* LOOK FOR STRATEGIC ENTRY: FEWER EXTREMISTS IN COMPETITIVE DISTRICTS? */

gen ran_safe = ran * (d_pres_vote_pct >= 65);
areg ideology ran ran_safe, absorb(Unique_ID) cluster(state);



/* REPUBLICANS */

use          ../pools_data/merged_data_33_reps_prev_cycle, clear;
rename Year year;
rename District dist;
rename Legislator_Party party;
gen name = Legislator;
rename Ideology ideology;
gen     type = "G" if Special == 0;
replace type = "S" if Special == 1;
merge m:1 state year dist type party name using ../other_data/cong_primaries_1996_2016;
gen byte ran = (w_p != .);
drop if _merge == 2;
drop _merge;
merge m:1 state dist year type using ../other_data/cong_incumbency;
drop if _merge == 2;
drop _merge;
merge m:1 state dist year type using ../other_data/pres_vote_to_use;
drop if _merge == 2;
drop _merge;
gen legislator_id = state + " " + name;

egen x = sum(w_p != .), by(Unique_ID);
* drop n;
egen n = count(year), by(Unique_ID);
keep if x >= 1;
keep if n >= 2;
drop x n;

gen byte open_seat = (inc_D == 0 & inc_R == 0);
gen r_pres_vote_pct = 100 - d_pres_vote_pct;
* gen byte safe   = (r_pres_vote_pct >  57.5)                           if r_pres_vote_pct != .;
* gen byte compet = (r_pres_vote_pct >= 42.5 & r_pres_vote_pct <= 57.5) if r_pres_vote_pct != .;
  gen byte safe   = (r_pres_vote_pct >  55.0)                           if r_pres_vote_pct != .;
  gen byte compet = (r_pres_vote_pct >= 45.0 & r_pres_vote_pct <= 55.0) if r_pres_vote_pct != .;

egen x = count(year), by(Unique_ID Legislator);
sort Unique_ID Legislator;
drop if x > 1 & Legislator == Legislator[_n-1];
drop x;

gen byte Won_Primary = 1 if w_p == 1;
replace  Won_Primary = 0 if Won_Primary == .;
gen byte Won_General = 1 if w_g == 1;
replace  Won_General = 0 if Won_General == .;

egen xmin = min(Won_Primary), by(Unique_ID);
egen xmax = max(Won_Primary), by(Unique_ID);
gen variation_Won_Primary = 1 if xmin < xmax;
drop xmin xmax;

egen xmin = min(Won_General), by(Unique_ID);
egen xmax = max(Won_General), by(Unique_ID);
gen variation_Won_General = 1 if xmin < xmax;
drop xmin xmax;

* egen x = pctile(ideology), p(1);
* drop if ideology < x;
* drop x;
* egen x = pctile(ideology), p(99);
* drop if ideology > x;
* drop x;

egen pool_size = count(ideology), by(Unique_ID);
egen pool_sd   = sd(ideology), by(Unique_ID);

save tmp1, replace;


collapse (mean) pool_size pool_sd, by(Unique_ID);

sum pool_size, detail;
local median_pool_size = r(p50);

sum pool_sd, detail;
local median_pool_sd = r(p50);


use tmp1, clear;


areg ideology ran,                   absorb(Unique_ID) cluster(state);
local b_r_R_1 =  _b[ran];
local s_r_R_1 = _se[ran];
local n_r_R_1 = e(N);

areg ideology ran if open_seat == 1, absorb(Unique_ID) cluster(state);
local b_r_R_2 =  _b[ran];
local s_r_R_2 = _se[ran]; 
local n_r_R_2 = e(N);

areg ideology ran if safe == 1,      absorb(Unique_ID) cluster(state);
local b_r_R_3 =  _b[ran];
local s_r_R_3 = _se[ran];
local n_r_R_3 = e(N);

areg ideology ran if compet == 1,    absorb(Unique_ID) cluster(state);
local b_r_R_4 =  _b[ran];
local s_r_R_4 = _se[ran];
local n_r_R_4 = e(N);

gen large = (pool_size > `median_pool_size') if pool_size != .;

xi: areg ideology i.ran*large, absorb(Unique_ID) cluster(state);

areg ideology ran if large == 1, absorb(Unique_ID) cluster(state);
local b_r_R_5 =  _b[ran];
local s_r_R_5 = _se[ran];
local n_r_R_5 = e(N);

areg ideology ran if large == 0, absorb(Unique_ID) cluster(state);
local b_r_R_6 =  _b[ran];
local s_r_R_6 = _se[ran];
local n_r_R_6 = e(N);


gen hi_sd = (pool_sd > `median_pool_sd') if pool_sd != .;

xi: areg ideology i.ran*hi_sd, absorb(Unique_ID) cluster(state);

areg ideology ran if hi_sd == 1, absorb(Unique_ID) cluster(state);
local b_r_R_7 =  _b[ran];
local s_r_R_7 = _se[ran];
local n_r_R_7 = e(N);

areg ideology ran if hi_sd == 0, absorb(Unique_ID) cluster(state);
local b_r_R_8 =  _b[ran];
local s_r_R_8 = _se[ran];
local n_r_R_8 = e(N);


areg ideology Won_Primary if variation_Won_Primary == 1,                  absorb(Unique_ID) cluster(state);
local b_p_R_1 =  _b[Won_Primary];
local s_p_R_1 = _se[Won_Primary];
local n_p_R_1 = e(N);

areg ideology Won_Primary if variation_Won_Primary == 1 & open_seat == 1, absorb(Unique_ID) cluster(state);
local b_p_R_2 =  _b[Won_Primary];
local s_p_R_2 = _se[Won_Primary];
local n_p_R_2 = e(N);

areg ideology Won_Primary if variation_Won_Primary == 1 & safe == 1,      absorb(Unique_ID) cluster(state);
local b_p_R_3 =  _b[Won_Primary];
local s_p_R_3 = _se[Won_Primary];
local n_p_R_3 = e(N);

areg ideology Won_Primary if variation_Won_Primary == 1 & compet == 1,    absorb(Unique_ID) cluster(state);
local b_p_R_4 =  _b[Won_Primary];
local s_p_R_4 = _se[Won_Primary];
local n_p_R_4 = e(N);


areg ideology Won_General if variation_Won_General == 1,                  absorb(Unique_ID) cluster(state);
local b_g_R_1 =  _b[Won_General];
local s_g_R_1 = _se[Won_General];
local n_g_R_1 = e(N);

areg ideology Won_General if variation_Won_General == 1 & open_seat == 1, absorb(Unique_ID) cluster(state);
local b_g_R_2 =  _b[Won_General];
local s_g_R_2 = _se[Won_General];
local n_g_R_2 = e(N);

areg ideology Won_General if variation_Won_General == 1 & safe == 1,      absorb(Unique_ID) cluster(state);
local b_g_R_3 =  _b[Won_General];
local s_g_R_3 = _se[Won_General];
local n_g_R_3 = e(N);

areg ideology Won_General if variation_Won_General == 1 & compet == 1,    absorb(Unique_ID) cluster(state);
local b_g_R_4 =  _b[Won_General];
local s_g_R_4 = _se[Won_General];
local n_g_R_4 = e(N);



/* AUXILLARY COMPARISONS */

gen Won_Primary_safe   = Won_Primary * (safe == 1);
gen Won_Primary_not    = Won_Primary * (safe == 0);
gen Won_Primary_compet = Won_Primary * (compet == 1);

areg ideology Won_Primary_safe Won_Primary_not if variation_Won_Primary == 1,      absorb(Unique_ID) cluster(state);
test Won_Primary_safe = Won_Primary_not;

areg ideology Won_Primary_safe Won_Primary_compet if variation_Won_Primary == 1 & (safe == 1 | compet == 1),      absorb(Unique_ID) cluster(state);
test Won_Primary_safe = Won_Primary_compet;

gen Won_General_safe   = Won_General * (safe == 1);
gen Won_General_not    = Won_General * (safe == 0);
gen Won_General_compet = Won_General * (compet == 1);

areg ideology Won_General_safe Won_General_not if variation_Won_General == 1,      absorb(Unique_ID) cluster(state);
test Won_General_safe = Won_General_not;

areg ideology Won_General_safe Won_General_compet if variation_Won_General == 1 & (safe == 1 | compet == 1),      absorb(Unique_ID) cluster(state);
test Won_General_safe = Won_General_compet;


/* LOOK FOR STRATEGIC ENTRY: FEWER EXTREMISTS IN COMPETITIVE DISTRICTS? */

gen ran_safe = ran * (d_pres_vote_pct < 35);
areg ideology ran ran_safe, absorb(Unique_ID) cluster(state);



/************************************************************/
/********** LATEX TABLE OF MAIN REGRESSION RESULTS **********/
/************************************************************/

quietly {;

  capture log close;
  log using ../output/tables/tbl_main_regressions_run_33_expanded_pool.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf Within-Pool Comparisons: NP-Score of State Legislators Who Run vs. Those Who Do Not -- Expanded Pool Including Retired State Legislators} ";
  noisily display "\label{tbl_main_regressions_run_33_expanded_pool} ";
  noisily display "\begin{tabular}{lcccccc} ";
  noisily display "\toprule\toprule ";
  noisily display "& \multicolumn{3}{c}{Democrats} & \multicolumn{3}{c}{~Republicans} \\ [.05in] "; 
  noisily display "Sample                 & Coeff.  & Std. Error  &  \# Obs.  & ~~Coeff.  &  Std. Error  &  \# Obs.  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "All pools              & " %4.3f `b_r_D_1' " & (" %4.3f `s_r_D_1' ") & [" %3.0f `n_r_D_1' "] & ~~" %4.3f `b_r_R_1' " & (" %4.3f `s_r_R_1' ") & [" %3.0f `n_r_R_1' "] \\ [.01in] "; 
  noisily display "Open seats             & " %4.3f `b_r_D_2' " & (" %4.3f `s_r_D_2' ") & [" %3.0f `n_r_D_2' "] & ~~" %4.3f `b_r_R_2' " & (" %4.3f `s_r_R_2' ") & [" %3.0f `n_r_R_2' "] \\ [.01in] "; 
  noisily display "Safe districts         & " %4.3f `b_r_D_3' " & (" %4.3f `s_r_D_3' ") & [" %3.0f `n_r_D_3' "] & ~~" %4.3f `b_r_R_3' " & (" %4.3f `s_r_R_3' ") & [" %3.0f `n_r_R_3' "] \\ [.01in] ";
  noisily display "Competitive districts  & " %4.3f `b_r_D_4' " & (" %4.3f `s_r_D_4' ") & [" %3.0f `n_r_D_4' "] & ~~" %4.3f `b_r_R_4' " & (" %4.3f `s_r_R_4' ") & [" %3.0f `n_r_R_4' "] \\ [.01in] "; 
  noisily display "Large pools            & " %4.3f `b_r_D_5' " & (" %4.3f `s_r_D_5' ") & [" %3.0f `n_r_D_5' "] & ~~" %4.3f `b_r_R_5' " & (" %4.3f `s_r_R_5' ") & [" %3.0f `n_r_R_5' "] \\ [.01in] ";
  noisily display "Small pools            & " %4.3f `b_r_D_6' " & (" %4.3f `s_r_D_6' ") & [" %3.0f `n_r_D_6' "] & ~~" %4.3f `b_r_R_6' " & (" %4.3f `s_r_R_6' ") & [" %3.0f `n_r_R_6' "] \\ [.01in] "; 
  noisily display "High-variance pools    & " %4.3f `b_r_D_7' " & (" %4.3f `s_r_D_7' ") & [" %3.0f `n_r_D_7' "] & ~~" %4.3f `b_r_R_7' " & (" %4.3f `s_r_R_7' ") & [" %3.0f `n_r_R_7' "] \\ [.01in] ";
  noisily display "Low-variance pools     & " %4.3f `b_r_D_8' " & (" %4.3f `s_r_D_8' ") & [" %3.0f `n_r_D_8' "] & ~~" %4.3f `b_r_R_8' " & (" %4.3f `s_r_R_8' ") & [" %3.0f `n_r_R_8' "] \\ [.01in] "; 

  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};


quietly {;

  capture log close;
  log using ../output/tables/tbl_main_regressions_win_prim_genl_33_expanded_pool.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf Within-Pool Comparisons: NP-Score of State Legislators Who Win Primary or General Elections vs. Others -- Expanded Pool Including Retired State Legislators} ";
  noisily display "\label{tbl_main_regressions_win_prim_genl_33_expanded_pool} ";
  noisily display "\begin{tabular}{lcccccc} ";
  noisily display "\toprule\toprule ";
  noisily display "& \multicolumn{3}{c}{Democrats} & \multicolumn{3}{c}{~Republicans} \\ [.05in] "; 
  noisily display "Sample                 & Coeff.  & Std. Error  &  \# Obs.  & ~~Coeff.  &  Std. Error  &  \# Obs.  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "\multicolumn{7}{l}{\textit{Primary Election Winners vs. Others in Pool}} \\ [0.01in] ";
  noisily display "All pools              & " %4.3f `b_p_D_1' " & (" %4.3f `s_p_D_1' ") & [" %3.0f `n_p_D_1' "] & ~~" %4.3f `b_p_R_1' " & (" %4.3f `s_p_R_1' ") & [" %3.0f `n_p_R_1' "] \\ [.01in] "; 
  noisily display "Safe districts         & " %4.3f `b_p_D_3' " & (" %4.3f `s_p_D_3' ") & [" %3.0f `n_p_D_3' "] & ~~" %4.3f `b_p_R_3' " & (" %4.3f `s_p_R_3' ") & [" %3.0f `n_p_R_3' "] \\ [.01in] ";
  noisily display "Competitive districts  & " %4.3f `b_p_D_4' " & (" %4.3f `s_p_D_4' ") & [" %3.0f `n_p_D_4' "] & ~~" %4.3f `b_p_R_4' " & (" %4.3f `s_p_R_4' ") & [" %3.0f `n_p_R_4' "] \\ [.01in] "; 
  noisily display "\midrule ";
  noisily display "\multicolumn{7}{l}{\textit{General Election Winners vs. Others in Pool}} \\ [0.01in] ";
  noisily display "All pools              & " %4.3f `b_g_D_1' " & (" %4.3f `s_g_D_1' ") & [" %3.0f `n_g_D_1' "] & ~~" %4.3f `b_g_R_1' " & (" %4.3f `s_g_R_1' ") & [" %3.0f `n_g_R_1' "] \\ [.01in] "; 
  noisily display "Safe districts         & " %4.3f `b_g_D_3' " & (" %4.3f `s_g_D_3' ") & [" %3.0f `n_g_D_3' "] & ~~" %4.3f `b_g_R_3' " & (" %4.3f `s_g_R_3' ") & [" %3.0f `n_g_R_3' "] \\ [.01in] ";
  noisily display "Competitive districts  & " %4.3f `b_g_D_4' " & (" %4.3f `s_g_D_4' ") & [" %3.0f `n_g_D_4' "] & ~~" %4.3f `b_g_R_4' " & (" %4.3f `s_g_R_4' ") & [" %3.0f `n_g_R_4' "] \\ [.01in] "; 
  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};



erase tmp1.dta;

