#delimit ;

set linesize 250;


/* MAIN ANALYSES OF WHO RUNS FROM POOL, AND WHO WINS PRIMARY AND GENERAL ELECTIONS */


/* DEMOCRATS */

use ../pools_data/merged_data_25_dems, clear;
keep if Contested == 1;
rename Year     year;
rename Ran      ran;
rename District dist;
rename Ideology ideology;
drop type;
gen     type = "G" if Special == 0;
replace type = "S" if Special == 1;
merge m:1 state dist year type using ../other_data/cong_incumbency;
drop if _merge == 2;
drop _merge;
merge m:1 state dist year type using ../other_data/pres_vote_to_use;
drop if _merge == 2;
drop _merge;
gen  party = "D";

gen byte open_seat = (inc_D == 0 & inc_R == 0);
* gen byte safe   = (d_pres_vote_pct >  57.5)                           if d_pres_vote_pct != .;
* gen byte compet = (d_pres_vote_pct >= 42.5 & d_pres_vote_pct <= 57.5) if d_pres_vote_pct != .;
  gen byte safe   = (d_pres_vote_pct >  55.0)                           if d_pres_vote_pct != .;
  gen byte compet = (d_pres_vote_pct >= 45.0 & d_pres_vote_pct <= 55.0) if d_pres_vote_pct != .;

egen x = count(year), by(Unique_ID Legislator);
sort Unique_ID Legislator;
drop if x > 1 & Legislator == Legislator[_n-1];
drop x;

replace Won_Primary = 0 if Won_Primary == .;
replace Won_General = 0 if Won_General == .;

egen xmin = min(Won_Primary), by(Unique_ID);
egen xmax = max(Won_Primary), by(Unique_ID);
gen variation_Won_Primary = 1 if xmin < xmax;
drop xmin xmax;

egen xmin = min(Won_General), by(Unique_ID);
egen xmax = max(Won_General), by(Unique_ID);
gen variation_Won_General = 1 if xmin < xmax;
drop xmin xmax;

* egen x = pctile(ideology), p(1);
* drop if ideology < x;
* drop x;
* egen x = pctile(ideology), p(99);
* drop if ideology > x;
* drop x;

egen ideology_rank = rank(ideology), by(party);
egen x = max(ideology_rank), by(party);
replace ideology_rank = ideology_rank/x;
drop x;

egen x = median(ideology), by(party);
gen ideology_dummy = ideology > x if ideology != .;
drop x;

egen pool_size = count(ideology), by(Unique_ID);
egen pool_sd   = sd(ideology), by(Unique_ID);

save tmp1, replace;


collapse (mean) pool_size pool_sd, by(Unique_ID);

sum pool_size, detail;
local median_pool_size = r(p50);

sum pool_sd, detail;
local median_pool_sd = r(p50);


use tmp1, clear;


areg ideology ran,                   absorb(Unique_ID) cluster(state);
local b_r_D_1 =  _b[ran];
local s_r_D_1 = _se[ran];
local n_r_D_1 = e(N);

areg ideology ran if open_seat == 1, absorb(Unique_ID) cluster(state);
local b_r_D_2 =  _b[ran];
local s_r_D_2 = _se[ran];
local n_r_D_2 = e(N);

areg ideology ran if safe == 1,      absorb(Unique_ID) cluster(state);
local b_r_D_3 =  _b[ran];
local s_r_D_3 = _se[ran];
local n_r_D_3 = e(N);

areg ideology ran if compet == 1,    absorb(Unique_ID) cluster(state);
local b_r_D_4 =  _b[ran];
local s_r_D_4 = _se[ran];
local n_r_D_4 = e(N);


gen large = (pool_size > `median_pool_size') if pool_size != .;

xi: areg ideology i.ran*large, absorb(Unique_ID) cluster(state);

areg ideology ran if large == 1, absorb(Unique_ID) cluster(state);
local b_r_D_5 =  _b[ran];
local s_r_D_5 = _se[ran];
local n_r_D_5 = e(N);

areg ideology ran if large == 0, absorb(Unique_ID) cluster(state);
local b_r_D_6 =  _b[ran];
local s_r_D_6 = _se[ran];
local n_r_D_6 = e(N);


gen hi_sd = (pool_sd > `median_pool_sd') if pool_sd != .;

xi: areg ideology i.ran*hi_sd, absorb(Unique_ID) cluster(state);

areg ideology ran if hi_sd == 1, absorb(Unique_ID) cluster(state);
local b_r_D_7 =  _b[ran];
local s_r_D_7 = _se[ran];
local n_r_D_7 = e(N);

areg ideology ran if hi_sd == 0, absorb(Unique_ID) cluster(state);
local b_r_D_8 =  _b[ran];
local s_r_D_8 = _se[ran];
local n_r_D_8 = e(N);


areg ideology Won_Primary if variation_Won_Primary == 1,                  absorb(Unique_ID) cluster(state);
local b_p_D_1 =  _b[Won_Primary];
local s_p_D_1 = _se[Won_Primary];
local n_p_D_1 = e(N);

areg ideology Won_Primary if variation_Won_Primary == 1 & open_seat == 1, absorb(Unique_ID) cluster(state);
local b_p_D_2 =  _b[Won_Primary];
local s_p_D_2 = _se[Won_Primary];
local n_p_D_2 = e(N);

areg ideology Won_Primary if variation_Won_Primary == 1 & safe == 1,      absorb(Unique_ID) cluster(state);
local b_p_D_3 =  _b[Won_Primary];
local s_p_D_3 = _se[Won_Primary];
local n_p_D_3 = e(N);

areg ideology Won_Primary if variation_Won_Primary == 1 & compet == 1,    absorb(Unique_ID) cluster(state);
local b_p_D_4 =  _b[Won_Primary];
local s_p_D_4 = _se[Won_Primary];
local n_p_D_4 = e(N);


areg ideology Won_General if variation_Won_General == 1,                  absorb(Unique_ID) cluster(state);
local b_g_D_1 =  _b[Won_General];
local s_g_D_1 = _se[Won_General];
local n_g_D_1 = e(N);

areg ideology Won_General if variation_Won_General == 1 & open_seat == 1, absorb(Unique_ID) cluster(state);
local b_g_D_2 =  _b[Won_General];
local s_g_D_2 = _se[Won_General];
local n_g_D_2 = e(N);

areg ideology Won_General if variation_Won_General == 1 & safe == 1,      absorb(Unique_ID) cluster(state);
local b_g_D_3 =  _b[Won_General];
local s_g_D_3 = _se[Won_General];
local n_g_D_3 = e(N);

areg ideology Won_General if variation_Won_General == 1 & compet == 1,    absorb(Unique_ID) cluster(state);
local b_g_D_4 =  _b[Won_General];
local s_g_D_4 = _se[Won_General];
local n_g_D_4 = e(N);



/* REGRESSIONS USING RANK OF IDEOLOGY AND DUMMY VERSION */

areg ideology_rank ran,                   absorb(Unique_ID) cluster(state);
local b_r_D_1_rank =  _b[ran];
local s_r_D_1_rank = _se[ran];
local n_r_D_1_rank = e(N);

areg ideology_rank ran if open_seat == 1, absorb(Unique_ID) cluster(state);
local b_r_D_2_rank =  _b[ran];
local s_r_D_2_rank = _se[ran];
local n_r_D_2_rank = e(N);

areg ideology_rank ran if safe == 1,      absorb(Unique_ID) cluster(state);
local b_r_D_3_rank =  _b[ran];
local s_r_D_3_rank = _se[ran];
local n_r_D_3_rank = e(N);

areg ideology_rank ran if compet == 1,    absorb(Unique_ID) cluster(state);
local b_r_D_4_rank =  _b[ran];
local s_r_D_4_rank = _se[ran];
local n_r_D_4_rank = e(N);


areg ideology_dummy ran,                   absorb(Unique_ID) cluster(state);
local b_r_D_1_dummy =  _b[ran];
local s_r_D_1_dummy = _se[ran];
local n_r_D_1_dummy = e(N);

areg ideology_dummy ran if open_seat == 1, absorb(Unique_ID) cluster(state);
local b_r_D_2_dummy =  _b[ran];
local s_r_D_2_dummy = _se[ran];
local n_r_D_2_dummy = e(N);

areg ideology_dummy ran if safe == 1,      absorb(Unique_ID) cluster(state);
local b_r_D_3_dummy =  _b[ran];
local s_r_D_3_dummy = _se[ran];
local n_r_D_3_dummy = e(N);

areg ideology_dummy ran if compet == 1,    absorb(Unique_ID) cluster(state);
local b_r_D_4_dummy =  _b[ran];
local s_r_D_4_dummy = _se[ran];
local n_r_D_4_dummy = e(N);


/* LOOK FOR STRATEGIC ENTRY: FEWER EXTREMISTS IN COMPETITIVE DISTRICTS? */

gen ran_safe = ran * (d_pres_vote_pct >= 65);
areg ideology ran ran_safe, absorb(Unique_ID) cluster(state);



/* REPUBLICANS */

use ../pools_data/merged_data_25_reps, clear;
keep if Contested == 1;
rename Year     year;
rename Ran      ran;
rename District dist;
rename Ideology ideology;
drop type;
gen     type = "G" if Special == 0;
replace type = "S" if Special == 1;
merge m:1 state dist year type using ../other_data/cong_incumbency;
drop if _merge == 2;
drop _merge;
merge m:1 state dist year type using ../other_data/pres_vote_to_use;
drop if _merge == 2;
drop _merge;
gen  party = "R";

gen byte open_seat = (inc_D == 0 & inc_R == 0);
gen r_pres_vote_pct = 100 - d_pres_vote_pct;
* gen byte safe   = (r_pres_vote_pct >  57.5)                           if r_pres_vote_pct != .;
* gen byte compet = (r_pres_vote_pct >= 42.5 & r_pres_vote_pct <= 57.5) if r_pres_vote_pct != .;
  gen byte safe   = (r_pres_vote_pct >  55.0)                           if r_pres_vote_pct != .;
  gen byte compet = (r_pres_vote_pct >= 45.0 & r_pres_vote_pct <= 55.0) if r_pres_vote_pct != .;

egen x = count(year), by(Unique_ID Legislator);
sort Unique_ID Legislator;
drop if x > 1 & Legislator == Legislator[_n-1];
drop x;

replace Won_Primary = 0 if Won_Primary == .;
replace Won_General = 0 if Won_General == .;

egen xmin = min(Won_Primary), by(Unique_ID);
egen xmax = max(Won_Primary), by(Unique_ID);
gen variation_Won_Primary = 1 if xmin < xmax;
drop xmin xmax;

egen xmin = min(Won_General), by(Unique_ID);
egen xmax = max(Won_General), by(Unique_ID);
gen variation_Won_General = 1 if xmin < xmax;
drop xmin xmax;

* egen x = pctile(ideology), p(1);
* drop if ideology < x;
* drop x;
* egen x = pctile(ideology), p(99);
* drop if ideology > x;
* drop x;

egen ideology_rank = rank(ideology), by(party);
egen x = max(ideology_rank), by(party);
replace ideology_rank = ideology_rank/x;
drop x;

egen x = median(ideology), by(party);
gen ideology_dummy = ideology > x if ideology != .;
drop x;

egen pool_size = count(ideology), by(Unique_ID);
egen pool_sd   = sd(ideology), by(Unique_ID);

save tmp1, replace;


collapse (mean) pool_size pool_sd, by(Unique_ID);

sum pool_size, detail;
local median_pool_size = r(p50);

sum pool_sd, detail;
local median_pool_sd = r(p50);


use tmp1, clear;


areg ideology ran,                   absorb(Unique_ID) cluster(state);
local b_r_R_1 =  _b[ran];
local s_r_R_1 = _se[ran];
local n_r_R_1 = e(N);

areg ideology ran if open_seat == 1, absorb(Unique_ID) cluster(state);
local b_r_R_2 =  _b[ran];
local s_r_R_2 = _se[ran]; 
local n_r_R_2 = e(N);

areg ideology ran if safe == 1,      absorb(Unique_ID) cluster(state);
local b_r_R_3 =  _b[ran];
local s_r_R_3 = _se[ran];
local n_r_R_3 = e(N);

areg ideology ran if compet == 1,    absorb(Unique_ID) cluster(state);
local b_r_R_4 =  _b[ran];
local s_r_R_4 = _se[ran];
local n_r_R_4 = e(N);

gen large = (pool_size > `median_pool_size') if pool_size != .;

xi: areg ideology i.ran*large, absorb(Unique_ID) cluster(state);

areg ideology ran if large == 1, absorb(Unique_ID) cluster(state);
local b_r_R_5 =  _b[ran];
local s_r_R_5 = _se[ran];
local n_r_R_5 = e(N);

areg ideology ran if large == 0, absorb(Unique_ID) cluster(state);
local b_r_R_6 =  _b[ran];
local s_r_R_6 = _se[ran];
local n_r_R_6 = e(N);


gen hi_sd = (pool_sd > `median_pool_sd') if pool_sd != .;

xi: areg ideology i.ran*hi_sd, absorb(Unique_ID) cluster(state);

areg ideology ran if hi_sd == 1, absorb(Unique_ID) cluster(state);
local b_r_R_7 =  _b[ran];
local s_r_R_7 = _se[ran];
local n_r_R_7 = e(N);

areg ideology ran if hi_sd == 0, absorb(Unique_ID) cluster(state);
local b_r_R_8 =  _b[ran];
local s_r_R_8 = _se[ran];
local n_r_R_8 = e(N);


areg ideology Won_Primary if variation_Won_Primary == 1,                  absorb(Unique_ID) cluster(state);
local b_p_R_1 =  _b[Won_Primary];
local s_p_R_1 = _se[Won_Primary];
local n_p_R_1 = e(N);

areg ideology Won_Primary if variation_Won_Primary == 1 & open_seat == 1, absorb(Unique_ID) cluster(state);
local b_p_R_2 =  _b[Won_Primary];
local s_p_R_2 = _se[Won_Primary];
local n_p_R_2 = e(N);

areg ideology Won_Primary if variation_Won_Primary == 1 & safe == 1,      absorb(Unique_ID) cluster(state);
local b_p_R_3 =  _b[Won_Primary];
local s_p_R_3 = _se[Won_Primary];
local n_p_R_3 = e(N);

areg ideology Won_Primary if variation_Won_Primary == 1 & compet == 1,    absorb(Unique_ID) cluster(state);
local b_p_R_4 =  _b[Won_Primary];
local s_p_R_4 = _se[Won_Primary];
local n_p_R_4 = e(N);


areg ideology Won_General if variation_Won_General == 1,                  absorb(Unique_ID) cluster(state);
local b_g_R_1 =  _b[Won_General];
local s_g_R_1 = _se[Won_General];
local n_g_R_1 = e(N);

areg ideology Won_General if variation_Won_General == 1 & open_seat == 1, absorb(Unique_ID) cluster(state);
local b_g_R_2 =  _b[Won_General];
local s_g_R_2 = _se[Won_General];
local n_g_R_2 = e(N);

areg ideology Won_General if variation_Won_General == 1 & safe == 1,      absorb(Unique_ID) cluster(state);
local b_g_R_3 =  _b[Won_General];
local s_g_R_3 = _se[Won_General];
local n_g_R_3 = e(N);

areg ideology Won_General if variation_Won_General == 1 & compet == 1,    absorb(Unique_ID) cluster(state);
local b_g_R_4 =  _b[Won_General];
local s_g_R_4 = _se[Won_General];
local n_g_R_4 = e(N);


/* REGRESSIONS USING RANK OF IDEOLOGY AND DUMMY VERSION */

areg ideology_rank ran,                   absorb(Unique_ID) cluster(state);
local b_r_R_1_rank =  _b[ran];
local s_r_R_1_rank = _se[ran];
local n_r_R_1_rank = e(N);

areg ideology_rank ran if open_seat == 1, absorb(Unique_ID) cluster(state);
local b_r_R_2_rank =  _b[ran];
local s_r_R_2_rank = _se[ran];
local n_r_R_2_rank = e(N);

areg ideology_rank ran if safe == 1,      absorb(Unique_ID) cluster(state);
local b_r_R_3_rank =  _b[ran];
local s_r_R_3_rank = _se[ran];
local n_r_R_3_rank = e(N);

areg ideology_rank ran if compet == 1,    absorb(Unique_ID) cluster(state);
local b_r_R_4_rank =  _b[ran];
local s_r_R_4_rank = _se[ran];
local n_r_R_4_rank = e(N);


areg ideology_dummy ran,                   absorb(Unique_ID) cluster(state);
local b_r_R_1_dummy =  _b[ran];
local s_r_R_1_dummy = _se[ran];
local n_r_R_1_dummy = e(N);

areg ideology_dummy ran if open_seat == 1, absorb(Unique_ID) cluster(state);
local b_r_R_2_dummy =  _b[ran];
local s_r_R_2_dummy = _se[ran];
local n_r_R_2_dummy = e(N);

areg ideology_dummy ran if safe == 1,      absorb(Unique_ID) cluster(state);
local b_r_R_3_dummy =  _b[ran];
local s_r_R_3_dummy = _se[ran];
local n_r_R_3_dummy = e(N);

areg ideology_dummy ran if compet == 1,    absorb(Unique_ID) cluster(state);
local b_r_R_4_dummy =  _b[ran];
local s_r_R_4_dummy = _se[ran];
local n_r_R_4_dummy = e(N);


/* AUXILLARY COMPARISONS */

gen Won_Primary_safe   = Won_Primary * (safe == 1);
gen Won_Primary_not    = Won_Primary * (safe == 0);
gen Won_Primary_compet = Won_Primary * (compet == 1);

areg ideology Won_Primary_safe Won_Primary_not if variation_Won_Primary == 1,      absorb(Unique_ID) cluster(state);
test Won_Primary_safe = Won_Primary_not;

areg ideology Won_Primary_safe Won_Primary_compet if variation_Won_Primary == 1 & (safe == 1 | compet == 1),      absorb(Unique_ID) cluster(state);
test Won_Primary_safe = Won_Primary_compet;

gen Won_General_safe   = Won_General * (safe == 1);
gen Won_General_not    = Won_General * (safe == 0);
gen Won_General_compet = Won_General * (compet == 1);

areg ideology Won_General_safe Won_General_not if variation_Won_General == 1,      absorb(Unique_ID) cluster(state);
test Won_General_safe = Won_General_not;

areg ideology Won_General_safe Won_General_compet if variation_Won_General == 1 & (safe == 1 | compet == 1),      absorb(Unique_ID) cluster(state);
test Won_General_safe = Won_General_compet;


/* LOOK FOR STRATEGIC ENTRY: FEWER EXTREMISTS IN COMPETITIVE DISTRICTS? */

gen ran_safe = ran * (d_pres_vote_pct < 35);
areg ideology ran ran_safe, absorb(Unique_ID) cluster(state);



/************************************************************/
/********** LATEX TABLE OF MAIN REGRESSION RESULTS **********/
/************************************************************/

quietly {;

  capture log close;
  log using ../output/tables/tbl_main_regressions_run_25.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf Within-Pool Comparisons: NP-Score of State Legislators Who Run vs. Those Who Do Not (Threshold to Define Pools = 25 Percent)} ";
  noisily display "\label{tbl_main_regressions_run_25} ";
  noisily display "\begin{tabular}{lcccccc} ";
  noisily display "\toprule\toprule ";
  noisily display "& \multicolumn{3}{c}{Democrats} & \multicolumn{3}{c}{~Republicans} \\ [.05in] "; 
  noisily display "Sample                 & Coeff.  & Std. Error  &  \# Obs.  & ~~Coeff.  &  Std. Error  &  \# Obs.  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "All pools              & " %4.3f `b_r_D_1' " & (" %4.3f `s_r_D_1' ") & [" %3.0f `n_r_D_1' "] & ~~" %4.3f `b_r_R_1' " & (" %4.3f `s_r_R_1' ") & [" %3.0f `n_r_R_1' "] \\ [.01in] "; 
  noisily display "Open seats             & " %4.3f `b_r_D_2' " & (" %4.3f `s_r_D_2' ") & [" %3.0f `n_r_D_2' "] & ~~" %4.3f `b_r_R_2' " & (" %4.3f `s_r_R_2' ") & [" %3.0f `n_r_R_2' "] \\ [.01in] "; 
  noisily display "Safe districts         & " %4.3f `b_r_D_3' " & (" %4.3f `s_r_D_3' ") & [" %3.0f `n_r_D_3' "] & ~~" %4.3f `b_r_R_3' " & (" %4.3f `s_r_R_3' ") & [" %3.0f `n_r_R_3' "] \\ [.01in] ";
  noisily display "Competitive districts  & " %4.3f `b_r_D_4' " & (" %4.3f `s_r_D_4' ") & [" %3.0f `n_r_D_4' "] & ~~" %4.3f `b_r_R_4' " & (" %4.3f `s_r_R_4' ") & [" %3.0f `n_r_R_4' "] \\ [.01in] "; 

  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};



quietly {;

  capture log close;
  log using ../output/tables/tbl_main_regressions_win_prim_genl_25.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf Within-Pool Comparisons: NP-Score of State Legislators Who Win Primary or General Elections vs. Others (Threshold to Define Pools = 25 Percent)} ";
  noisily display "\label{tbl_main_regressions_win_prim_genl_25} ";
  noisily display "\begin{tabular}{lcccccc} ";
  noisily display "\toprule\toprule ";
  noisily display "& \multicolumn{3}{c}{Democrats} & \multicolumn{3}{c}{~Republicans} \\ [.05in] "; 
  noisily display "Sample                 & Coeff.  & Std. Error  &  \# Obs.  & ~~Coeff.  &  Std. Error  &  \# Obs.  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "\multicolumn{7}{l}{\textit{Primary Election Winners vs. Others in Pool}} \\ [0.01in] ";
  noisily display "All pools              & " %4.3f `b_p_D_1' " & (" %4.3f `s_p_D_1' ") & [" %3.0f `n_p_D_1' "] & ~~" %4.3f `b_p_R_1' " & (" %4.3f `s_p_R_1' ") & [" %3.0f `n_p_R_1' "] \\ [.01in] "; 
  noisily display "Safe districts         & " %4.3f `b_p_D_3' " & (" %4.3f `s_p_D_3' ") & [" %3.0f `n_p_D_3' "] & ~~" %4.3f `b_p_R_3' " & (" %4.3f `s_p_R_3' ") & [" %3.0f `n_p_R_3' "] \\ [.01in] ";
  noisily display "Competitive districts  & " %4.3f `b_p_D_4' " & (" %4.3f `s_p_D_4' ") & [" %3.0f `n_p_D_4' "] & ~~" %4.3f `b_p_R_4' " & (" %4.3f `s_p_R_4' ") & [" %3.0f `n_p_R_4' "] \\ [.01in] "; 
  noisily display "\midrule ";
  noisily display "\multicolumn{7}{l}{\textit{General Election Winners vs. Others in Pool}} \\ [0.01in] ";
  noisily display "All pools              & " %4.3f `b_g_D_1' " & (" %4.3f `s_g_D_1' ") & [" %3.0f `n_g_D_1' "] & ~~" %4.3f `b_g_R_1' " & (" %4.3f `s_g_R_1' ") & [" %3.0f `n_g_R_1' "] \\ [.01in] "; 
  noisily display "Safe districts         & " %4.3f `b_g_D_3' " & (" %4.3f `s_g_D_3' ") & [" %3.0f `n_g_D_3' "] & ~~" %4.3f `b_g_R_3' " & (" %4.3f `s_g_R_3' ") & [" %3.0f `n_g_R_3' "] \\ [.01in] ";
  noisily display "Competitive districts  & " %4.3f `b_g_D_4' " & (" %4.3f `s_g_D_4' ") & [" %3.0f `n_g_D_4' "] & ~~" %4.3f `b_g_R_4' " & (" %4.3f `s_g_R_4' ") & [" %3.0f `n_g_R_4' "] \\ [.01in] "; 
  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};


erase tmp1.dta;

