#delimit ;

set linesize 250;


/* ANALYSES OF IDEOLOGICAL DIFFERENCES BETWEEN RUNNERS AND NON-RUNNERS */

/* SUMMARY STATISTICS OF WHO RUNS AND WHO DOES NOT */

use ../pools_data/merged_data_33_dems, clear;
append using ../pools_data/merged_data_33_reps;
rename Year     year;
rename Ran      ran;
rename District dist;
rename Ideology ideology;
drop type;
gen     type = "G" if Special == 0;
replace type = "S" if Special == 1;
merge m:1 state dist year type using ../other_data/cong_incumbency;
drop if _merge == 2;
drop _merge;
merge m:1 state dist year type using ../other_data/pres_vote_to_use;
drop if _merge == 2;
drop _merge;
rename Legislator_Party party;
gen legislator_id = state + " " + Legislator;

gsort state Legislator party year -ran Unique_ID;
gen use_in_summaries = 1 if !(state == state[_n-1] & Legislator == Legislator[_n-1] & party == party[_n-1] & year == year[_n-1]);

egen ideology_rank = rank(ideology) if use_in_summaries == 1, by(party);
egen x = max(ideology_rank)         if use_in_summaries == 1, by(party);
replace ideology_rank = ideology_rank/x;
drop x;

egen x = median(ideology) if use_in_summaries == 1, by(party);
gen ideology_dummy = ideology > x if ideology != . & use_in_summaries == 1;
drop x;

egen x = median(ideology), by(Unique_ID);
gen ideology_dummy2 = ideology > x if ideology != .;
egen xx = count(year), by(Unique_ID);
replace ideology_dummy2 = . if xx <= 2;
drop x xx;

sum ideology if party == "D" & ran == 1 & use_in_summaries == 1;
local mean_ran_D = r(mean);
local N_ran_D = r(N);

sum ideology if party == "D" & ran == 0 & use_in_summaries == 1;
local mean_not_D = r(mean);
local N_not_D = r(N);

sum ideology if party == "R" & ran == 1 & use_in_summaries == 1;
local mean_ran_R = r(mean);
local N_ran_R = r(N);

sum ideology if party == "R" & ran == 0 & use_in_summaries == 1;
local mean_not_R = r(mean);
local N_not_R = r(N);

ttest ideology    if party == "D" & use_in_summaries == 1, by(ran);
reg  ideology ran if party == "D" & use_in_summaries == 1, cluster(legislator_id);
areg ideology ran if party == "D" & use_in_summaries == 1, a(state) cluster(legislator_id);
ttest ideology    if party == "R" & use_in_summaries == 1, by(ran);
reg  ideology ran if party == "R" & use_in_summaries == 1, cluster(legislator_id);
areg ideology ran if party == "R" & use_in_summaries == 1, a(state) cluster(legislator_id);


/******************************************************************************/
/********** LATEX TABLE OF SUMMARY STATS FOR RUNNERS AND NON-RUNNERS **********/
/******************************************************************************/

quietly {;

  capture log close;
  log using ../output/tables/tbl_summary_runners_nonrunners_33.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf NP-Score of state legislators who run vs. those who do not.} ";
  noisily display "\label{tbl_summary_runners_nonrunners_33} ";
  noisily display "\begin{tabular}{lcrcr} ";
  noisily display "\toprule\toprule ";
  noisily display "& \multicolumn{2}{c}{Democrats} & \multicolumn{2}{c}{Republicans} \\ [.05in] "; 
  noisily display "            & Mean        &          & Mean       &          \\ ";
  noisily display "Item        & NP-Score    & \# Obs.  & NP-Score   & \# Obs.  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "Ran for Congress  & " %6.3f `mean_ran_D' " & " %6.0fc `N_ran_D' " & " %6.3f `mean_ran_R' " & " %6.0fc `N_ran_R' " \\ [.01in] "; 
  noisily display "Did Not Run       & " %6.3f `mean_not_D' " & " %6.0fc `N_not_D' " & " %6.3f `mean_not_R' " & " %6.0fc `N_not_R' " \\ [.01in] "; 
  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};

gen     ideology_graph = ideology;
replace ideology_graph = -2.1 if party == "D" & ideology < -2.1 ;
replace ideology_graph =  2.1 if party == "D" & ideology >  2.1 & ideology != .;
replace ideology_graph = -2.1 if party == "R" & ideology < -2.1 ;
replace ideology_graph =  2.1 if party == "R" & ideology >  2.1 & ideology != .;
replace ideology_graph = . if use_in_summaries != 1;

kdensity ideology_graph if party=="D" & ran == 0, bwidth(.15) lwidth(medthick) lcolor(gs10)
addplot(kdensity ideology_graph if party == "D" & ran == 1, bwidth(.15) lwidth(medthick) lcolor(gs0)) 
plotregion(style(none)) graphregion(fcolor(white) lcolor(white))
xtitle("NP Score") title("Democrats") legend(off) xlabel(-2 -1 0 1) text(0.30 -1.77 "Ran") text(0.53 0 "Did Not Run", color(gs10));
graph export ../output/figures/kernal_density_D_33.pdf, replace;

kdensity ideology_graph if party=="R" & ran == 0, bwidth(.15) lwidth(medthick) lcolor(gs10)
addplot(kdensity ideology_graph if party == "R" & ran == 1, bwidth(.15) lwidth(medthick) lcolor(gs0)) 
plotregion(style(none)) graphregion(fcolor(white) lcolor(white))
xtitle("NP Score") title("Republicans") legend(off) xlabel(1 -1 0 2) text(0.30 1.73 "Ran") text(0.53 0 "Did Not Run", color(gs10));
graph export ../output/figures/kernal_density_R_33.pdf, replace;


/* NUMBERS FOR FOOTNOTE AFTER TABLE, FOR MEDIANS RATHER THAN MEANS */

sum ideology if party == "D" & ran == 1 & use_in_summaries == 1, detail;
local med_ran_D = r(p50);

sum ideology if party == "D" & ran == 0 & use_in_summaries == 1, detail;
local med_not_D = r(p50);

sum ideology if party == "R" & ran == 1 & use_in_summaries == 1, detail;
local med_ran_R = r(p50);

sum ideology if party == "R" & ran == 0 & use_in_summaries == 1, detail;
local med_not_R = r(p50);

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_19.tex, text replace;
  noisily display %5.3f `med_ran_R' - `med_not_R';
  log close;
};

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_20.tex, text replace;
  noisily display %5.3f `med_ran_D' - `med_not_D';
  log close;
};



/* SAME AS ABOVE BUT WITH RANK OF IDEOLOGY */

sum ideology_rank if party == "D" & ran == 1 & use_in_summaries == 1;
local mean_ran_D = r(mean);
local N_ran_D = r(N);

sum ideology_rank if party == "D" & ran == 0 & use_in_summaries == 1;
local mean_not_D = r(mean);
local N_not_D = r(N);

sum ideology_rank if party == "R" & ran == 1 & use_in_summaries == 1;
local mean_ran_R = r(mean);
local N_ran_R = r(N);

sum ideology_rank if party == "R" & ran == 0 & use_in_summaries == 1;
local mean_not_R = r(mean);
local N_not_R = r(N);

ttest ideology_rank    if party == "D" & use_in_summaries == 1, by(ran);
reg  ideology_rank ran if party == "D" & use_in_summaries == 1, cluster(legislator_id);
areg ideology_rank ran if party == "D" & use_in_summaries == 1, a(state) cluster(legislator_id);
ttest ideology_rank    if party == "R" & use_in_summaries == 1, by(ran);
reg  ideology_rank ran if party == "R" & use_in_summaries == 1, cluster(legislator_id);
areg ideology_rank ran if party == "R" & use_in_summaries == 1, a(state) cluster(legislator_id);


/******************************************************************************/
/********** LATEX TABLE OF SUMMARY STATS FOR RUNNERS AND NON-RUNNERS **********/
/******************************************************************************/

quietly {;

  capture log close;
  log using ../output/tables/tbl_summary_runners_nonrunners_33_rank.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf NP-Score of State Legislators Who Run vs. Those Who Do Not, Rank of Ideology} ";
  noisily display "\label{tbl_summary_runners_nonrunners_33_rank} ";
  noisily display "\begin{tabular}{lcrcr} ";
  noisily display "\toprule\toprule ";
  noisily display "& \multicolumn{2}{c}{Democrats} & \multicolumn{2}{c}{Republicans} \\ [.05in] "; 
  noisily display "            & Mean          &          & Mean          &          \\ ";
  noisily display "Item        & NP-Score Rank & \# Obs.  & NP-Score Rank & \# Obs.  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "Ran for Congress  & " %6.3f `mean_ran_D' " & " %6.0fc `N_ran_D' " & " %6.3f `mean_ran_R' " & " %6.0fc `N_ran_R' " \\ [.01in] "; 
  noisily display "Did Not Run       & " %6.3f `mean_not_D' " & " %6.0fc `N_not_D' " & " %6.3f `mean_not_R' " & " %6.0fc `N_not_R' " \\ [.01in] "; 
  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};



/* SAME AS ABOVE BUT WITH "CONSERVATIVE" DUMMY */

sum ideology_dummy if party == "D" & ran == 1 & use_in_summaries == 1;
local mean_ran_D = r(mean);
local N_ran_D = r(N);

sum ideology_dummy if party == "D" & ran == 0 & use_in_summaries == 1;
local mean_not_D = r(mean);
local N_not_D = r(N);

sum ideology_dummy if party == "R" & ran == 1 & use_in_summaries == 1;
local mean_ran_R = r(mean);
local N_ran_R = r(N);

sum ideology_dummy if party == "R" & ran == 0 & use_in_summaries == 1;
local mean_not_R = r(mean);
local N_not_R = r(N);

ttest ideology_dummy    if party == "D" & use_in_summaries == 1, by(ran);
reg  ideology_dummy ran if party == "D" & use_in_summaries == 1, cluster(legislator_id);
areg ideology_dummy ran if party == "D" & use_in_summaries == 1, a(state) cluster(legislator_id);
ttest ideology_dummy    if party == "R" & use_in_summaries == 1, by(ran);
reg  ideology_dummy ran if party == "R" & use_in_summaries == 1, cluster(legislator_id);
areg ideology_dummy ran if party == "R" & use_in_summaries == 1, a(state) cluster(legislator_id);


/******************************************************************************/
/********** LATEX TABLE OF SUMMARY STATS FOR RUNNERS AND NON-RUNNERS **********/
/******************************************************************************/

quietly {;

  capture log close;
  log using ../output/tables/tbl_summary_runners_nonrunners_33_dummy.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf NP-Score of State Legislators Who Run vs. Those Who Do Not, Dummy of Ideology} ";
  noisily display "\label{tbl_summary_runners_nonrunners_33_dummy} ";
  noisily display "\begin{tabular}{lcrcr} ";
  noisily display "\toprule\toprule ";
  noisily display "& \multicolumn{2}{c}{Democrats} & \multicolumn{2}{c}{Republicans} \\ [.05in] "; 
  noisily display "            & Mean            &          & Mean           &          \\ ";
  noisily display "Item        & NP-Score Dummy  & \# Obs.  & NP-Score Dummy & \# Obs.  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "Ran for Congress  & " %6.3f `mean_ran_D' " & " %6.0fc `N_ran_D' " & " %6.3f `mean_ran_R' " & " %6.0fc `N_ran_R' " \\ [.01in] "; 
  noisily display "Did Not Run       & " %6.3f `mean_not_D' " & " %6.0fc `N_not_D' " & " %6.3f `mean_not_R' " & " %6.0fc `N_not_R' " \\ [.01in] "; 
  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};



/* SAME AS ABOVE BUT WITH "EXTREME RELATIVE TO POOL" DUMMY */

sum ideology_dummy2 if party == "D" & ran == 1;
local mean_ran_D = r(mean);
local N_ran_D = r(N);

sum ideology_dummy2 if party == "D" & ran == 0;
local mean_not_D = r(mean);
local N_not_D = r(N);

sum ideology_dummy2 if party == "R" & ran == 1;
local mean_ran_R = r(mean);
local N_ran_R = r(N);

sum ideology_dummy2 if party == "R" & ran == 0;
local mean_not_R = r(mean);
local N_not_R = r(N);

ttest ideology_dummy2 if party == "D", by(ran);
reg  ideology_dummy2 ran if party == "D", cluster(legislator_id);
areg ideology_dummy2 ran if party == "D", a(state) cluster(legislator_id);
ttest ideology_dummy2 if party == "R", by(ran);
reg  ideology_dummy2 ran if party == "R", cluster(legislator_id);
areg ideology_dummy2 ran if party == "R", a(state) cluster(legislator_id);


/******************************************************************************/
/********** LATEX TABLE OF SUMMARY STATS FOR RUNNERS AND NON-RUNNERS **********/
/******************************************************************************/

quietly {;

  capture log close;
  log using ../output/tables/tbl_summary_runners_nonrunners_33_dummy2.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf NP-Score of State Legislators Who Run vs. Those Who Do Not, Dummy of Ideology Relative to Pool} ";
  noisily display "\label{tbl_summary_runners_nonrunners_33_dummy2} ";
  noisily display "\begin{tabular}{lcrcr} ";
  noisily display "\toprule\toprule ";
  noisily display "& \multicolumn{2}{c}{Democrats} & \multicolumn{2}{c}{Republicans} \\ [.05in] "; 
  noisily display "            & Mean NP-Score    &          & Mean NP-Score   &          \\ ";
  noisily display "Item        & Dummy Relative   & \# Obs.  & Dummy Relative  & \# Obs.  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "Ran for Congress  & " %6.3f `mean_ran_D' " & " %6.0fc `N_ran_D' " & " %6.3f `mean_ran_R' " & " %6.0fc `N_ran_R' " \\ [.01in] "; 
  noisily display "Did Not Run       & " %6.3f `mean_not_D' " & " %6.0fc `N_not_D' " & " %6.3f `mean_not_R' " & " %6.0fc `N_not_R' " \\ [.01in] "; 
  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};

/* MAIN ANALYSES OF WHO RUNS FROM POOL, AND WHO WINS PRIMARY AND GENERAL ELECTIONS */

/* DEMOCRATS */

use ../pools_data/merged_data_33_dems, clear;
keep if Contested == 1;
rename Year     year;
rename Ran      ran;
rename District dist;
rename Ideology ideology;
drop type;
gen     type = "G" if Special == 0;
replace type = "S" if Special == 1;
merge m:1 state dist year type using ../other_data/cong_incumbency;
drop if _merge == 2;
drop _merge;
merge m:1 state dist year type using ../other_data/pres_vote_to_use;
drop if _merge == 2;
drop _merge;
gen  party = "D";

gen byte open_seat = (inc_D == 0 & inc_R == 0);
gen byte safe   = (d_pres_vote_pct >  55.0)                           if d_pres_vote_pct != .;
gen byte compet = (d_pres_vote_pct >= 45.0 & d_pres_vote_pct <= 55.0) if d_pres_vote_pct != .;

egen x = count(year), by(Unique_ID Legislator);
sort Unique_ID Legislator;
drop if x > 1 & Legislator == Legislator[_n-1];
drop x;

replace Won_Primary = 0 if Won_Primary == .;
replace Won_Primary = 1 if Won_Primary == 2;
replace Won_General = 0 if Won_General == .;

egen xmin = min(Won_Primary), by(Unique_ID);
egen xmax = max(Won_Primary), by(Unique_ID);
gen variation_Won_Primary = 1 if xmin < xmax;
drop xmin xmax;

egen xmin = min(Won_General), by(Unique_ID);
egen xmax = max(Won_General), by(Unique_ID);
gen variation_Won_General = 1 if xmin < xmax;
drop xmin xmax;

* egen x = pctile(ideology), p(1);
* drop if ideology < x;
* drop x;
* egen x = pctile(ideology), p(99);
* drop if ideology > x;
* drop x;

egen ideology_rank = rank(ideology), by(party);
egen x = max(ideology_rank), by(party);
replace ideology_rank = ideology_rank/x;
drop x;

egen x = median(ideology), by(party);
gen ideology_dummy = ideology > x if ideology != .;
drop x;

egen x = median(ideology), by(Unique_ID);
gen ideology_dummy2 = ideology > x if ideology != .;
egen xx = count(year), by(Unique_ID);
replace ideology_dummy2 = . if xx <= 2;
drop x xx;

egen pool_size = count(ideology), by(Unique_ID);
egen pool_sd   = sd(ideology), by(Unique_ID);

save tmp1, replace;


collapse (mean) pool_size pool_sd, by(Unique_ID);

sum pool_size, detail;
local median_pool_size = r(p50);

sum pool_sd, detail;
local median_pool_sd = r(p50);


use tmp1, clear;


areg ideology ran,                   absorb(Unique_ID) cluster(state);
local b_r_D_1 =  _b[ran];
local s_r_D_1 = _se[ran];
local n_r_D_1 = e(N);

areg ideology ran if open_seat == 1, absorb(Unique_ID) cluster(state);
local b_r_D_2 =  _b[ran];
local s_r_D_2 = _se[ran];
local n_r_D_2 = e(N);

areg ideology ran if safe == 1,      absorb(Unique_ID) cluster(state);
local b_r_D_3 =  _b[ran];
local s_r_D_3 = _se[ran];
local n_r_D_3 = e(N);

areg ideology ran if compet == 1,    absorb(Unique_ID) cluster(state);
local b_r_D_4 =  _b[ran];
local s_r_D_4 = _se[ran];
local n_r_D_4 = e(N);


gen large = (pool_size > `median_pool_size') if pool_size != .;

xi: areg ideology i.ran*large, absorb(Unique_ID) cluster(state);

areg ideology ran if large == 1, absorb(Unique_ID) cluster(state);
local b_r_D_5 =  _b[ran];
local s_r_D_5 = _se[ran];
local n_r_D_5 = e(N);

areg ideology ran if large == 0, absorb(Unique_ID) cluster(state);
local b_r_D_6 =  _b[ran];
local s_r_D_6 = _se[ran];
local n_r_D_6 = e(N);


gen hi_sd = (pool_sd > `median_pool_sd') if pool_sd != .;

xi: areg ideology i.ran*hi_sd, absorb(Unique_ID) cluster(state);

areg ideology ran if hi_sd == 1, absorb(Unique_ID) cluster(state);
local b_r_D_7 =  _b[ran];
local s_r_D_7 = _se[ran];
local n_r_D_7 = e(N);

areg ideology ran if hi_sd == 0, absorb(Unique_ID) cluster(state);
local b_r_D_8 =  _b[ran];
local s_r_D_8 = _se[ran];
local n_r_D_8 = e(N);


areg ideology Won_Primary if variation_Won_Primary == 1,                  absorb(Unique_ID) cluster(state);
local b_p_D_1 =  _b[Won_Primary];
local s_p_D_1 = _se[Won_Primary];
local n_p_D_1 = e(N);

areg ideology Won_Primary if variation_Won_Primary == 1 & open_seat == 1, absorb(Unique_ID) cluster(state);
local b_p_D_2 =  _b[Won_Primary];
local s_p_D_2 = _se[Won_Primary];
local n_p_D_2 = e(N);

areg ideology Won_Primary if variation_Won_Primary == 1 & safe == 1,      absorb(Unique_ID) cluster(state);
local b_p_D_3 =  _b[Won_Primary];
local s_p_D_3 = _se[Won_Primary];
local n_p_D_3 = e(N);

areg ideology Won_Primary if variation_Won_Primary == 1 & compet == 1,    absorb(Unique_ID) cluster(state);
local b_p_D_4 =  _b[Won_Primary];
local s_p_D_4 = _se[Won_Primary];
local n_p_D_4 = e(N);


areg ideology Won_General if variation_Won_General == 1,                  absorb(Unique_ID) cluster(state);
local b_g_D_1 =  _b[Won_General];
local s_g_D_1 = _se[Won_General];
local n_g_D_1 = e(N);

areg ideology Won_General if variation_Won_General == 1 & open_seat == 1, absorb(Unique_ID) cluster(state);
local b_g_D_2 =  _b[Won_General];
local s_g_D_2 = _se[Won_General];
local n_g_D_2 = e(N);

areg ideology Won_General if variation_Won_General == 1 & safe == 1,      absorb(Unique_ID) cluster(state);
local b_g_D_3 =  _b[Won_General];
local s_g_D_3 = _se[Won_General];
local n_g_D_3 = e(N);

areg ideology Won_General if variation_Won_General == 1 & compet == 1,    absorb(Unique_ID) cluster(state);
local b_g_D_4 =  _b[Won_General];
local s_g_D_4 = _se[Won_General];
local n_g_D_4 = e(N);



/* REGRESSIONS USING RANK OF IDEOLOGY AND DUMMY VERSION */

areg ideology_rank ran,                   absorb(Unique_ID) cluster(state);
local b_r_D_1_rank =  _b[ran];
local s_r_D_1_rank = _se[ran];
local n_r_D_1_rank = e(N);

areg ideology_rank ran if open_seat == 1, absorb(Unique_ID) cluster(state);
local b_r_D_2_rank =  _b[ran];
local s_r_D_2_rank = _se[ran];
local n_r_D_2_rank = e(N);

areg ideology_rank ran if safe == 1,      absorb(Unique_ID) cluster(state);
local b_r_D_3_rank =  _b[ran];
local s_r_D_3_rank = _se[ran];
local n_r_D_3_rank = e(N);

areg ideology_rank ran if compet == 1,    absorb(Unique_ID) cluster(state);
local b_r_D_4_rank =  _b[ran];
local s_r_D_4_rank = _se[ran];
local n_r_D_4_rank = e(N);


areg ideology_dummy ran,                   absorb(Unique_ID) cluster(state);
local b_r_D_1_dummy =  _b[ran];
local s_r_D_1_dummy = _se[ran];
local n_r_D_1_dummy = e(N);

areg ideology_dummy ran if open_seat == 1, absorb(Unique_ID) cluster(state);
local b_r_D_2_dummy =  _b[ran];
local s_r_D_2_dummy = _se[ran];
local n_r_D_2_dummy = e(N);

areg ideology_dummy ran if safe == 1,      absorb(Unique_ID) cluster(state);
local b_r_D_3_dummy =  _b[ran];
local s_r_D_3_dummy = _se[ran];
local n_r_D_3_dummy = e(N);

areg ideology_dummy ran if compet == 1,    absorb(Unique_ID) cluster(state);
local b_r_D_4_dummy =  _b[ran];
local s_r_D_4_dummy = _se[ran];
local n_r_D_4_dummy = e(N);


areg ideology_dummy2 ran,                   absorb(Unique_ID) cluster(state);
local b_r_D_1_dummy2 =  _b[ran];
local s_r_D_1_dummy2 = _se[ran];
local n_r_D_1_dummy2 = e(N);

areg ideology_dummy2 ran if open_seat == 1, absorb(Unique_ID) cluster(state);
local b_r_D_2_dummy2 =  _b[ran];
local s_r_D_2_dummy2 = _se[ran];
local n_r_D_2_dummy2 = e(N);

areg ideology_dummy2 ran if safe == 1,      absorb(Unique_ID) cluster(state);
local b_r_D_3_dummy2 =  _b[ran];
local s_r_D_3_dummy2 = _se[ran];
local n_r_D_3_dummy2 = e(N);

areg ideology_dummy2 ran if compet == 1,    absorb(Unique_ID) cluster(state);
local b_r_D_4_dummy2 =  _b[ran];
local s_r_D_4_dummy2 = _se[ran];
local n_r_D_4_dummy2 = e(N);


/* LOOK FOR STRATEGIC ENTRY: FEWER EXTREMISTS IN COMPETITIVE DISTRICTS? */

gen ran_verysafe = ran * (d_pres_vote_pct >= 65);
areg ideology ran ran_verysafe, absorb(Unique_ID) cluster(state);



/* CHECK FOR TRENDING IN WINNERS VS. POOL */

gen t = year - 2005;
xi: areg ideology i.Won_Primary*t if variation_Won_Primary == 1,                  absorb(Unique_ID) cluster(state);
xi: areg ideology i.Won_General*t if variation_Won_General == 1,                  absorb(Unique_ID) cluster(state);



/* REPUBLICANS */

use ../pools_data/merged_data_33_reps, clear;
keep if Contested == 1;
rename Year     year;
rename Ran      ran;
rename District dist;
rename Ideology ideology;
drop type;
gen     type = "G" if Special == 0;
replace type = "S" if Special == 1;
merge m:1 state dist year type using ../other_data/cong_incumbency;
drop if _merge == 2;
drop _merge;
merge m:1 state dist year type using ../other_data/pres_vote_to_use;
drop if _merge == 2;
drop _merge;
gen  party = "R";

gen byte open_seat = (inc_D == 0 & inc_R == 0);
gen r_pres_vote_pct = 100 - d_pres_vote_pct;
gen byte safe   = (r_pres_vote_pct >  55.0)                           if r_pres_vote_pct != .;
gen byte compet = (r_pres_vote_pct >= 45.0 & r_pres_vote_pct <= 55.0) if r_pres_vote_pct != .;

egen x = count(year), by(Unique_ID Legislator);
sort Unique_ID Legislator;
drop if x > 1 & Legislator == Legislator[_n-1];
drop x;

replace Won_Primary = 0 if Won_Primary == .;
replace Won_Primary = 1 if Won_Primary == 2;
replace Won_General = 0 if Won_General == .;

egen xmin = min(Won_Primary), by(Unique_ID);
egen xmax = max(Won_Primary), by(Unique_ID);
gen variation_Won_Primary = 1 if xmin < xmax;
drop xmin xmax;

egen xmin = min(Won_General), by(Unique_ID);
egen xmax = max(Won_General), by(Unique_ID);
gen variation_Won_General = 1 if xmin < xmax;
drop xmin xmax;

* egen x = pctile(ideology), p(1);
* drop if ideology < x;
* drop x;
* egen x = pctile(ideology), p(99);
* drop if ideology > x;
* drop x;

egen ideology_rank = rank(ideology), by(party);
egen x = max(ideology_rank), by(party);
replace ideology_rank = ideology_rank/x;
drop x;

egen x = median(ideology), by(party);
gen ideology_dummy = ideology > x if ideology != .;
drop x;

egen x = median(ideology), by(Unique_ID);
gen ideology_dummy2 = ideology > x if ideology != .;
egen xx = count(year), by(Unique_ID);
replace ideology_dummy2 = . if xx <= 2;
drop x xx;

egen pool_size = count(ideology), by(Unique_ID);
egen pool_sd   = sd(ideology), by(Unique_ID);

save tmp1, replace;


collapse (mean) pool_size pool_sd, by(Unique_ID);

sum pool_size, detail;
local median_pool_size = r(p50);

sum pool_sd, detail;
local median_pool_sd = r(p50);


use tmp1, clear;


areg ideology ran,                   absorb(Unique_ID) cluster(state);
local b_r_R_1 =  _b[ran];
local s_r_R_1 = _se[ran];
local n_r_R_1 = e(N);

areg ideology ran if open_seat == 1, absorb(Unique_ID) cluster(state);
local b_r_R_2 =  _b[ran];
local s_r_R_2 = _se[ran]; 
local n_r_R_2 = e(N);

areg ideology ran if safe == 1,      absorb(Unique_ID) cluster(state);
local b_r_R_3 =  _b[ran];
local s_r_R_3 = _se[ran];
local n_r_R_3 = e(N);

areg ideology ran if compet == 1,    absorb(Unique_ID) cluster(state);
local b_r_R_4 =  _b[ran];
local s_r_R_4 = _se[ran];
local n_r_R_4 = e(N);

gen large = (pool_size > `median_pool_size') if pool_size != .;

xi: areg ideology i.ran*large, absorb(Unique_ID) cluster(state);

areg ideology ran if large == 1, absorb(Unique_ID) cluster(state);
local b_r_R_5 =  _b[ran];
local s_r_R_5 = _se[ran];
local n_r_R_5 = e(N);

areg ideology ran if large == 0, absorb(Unique_ID) cluster(state);
local b_r_R_6 =  _b[ran];
local s_r_R_6 = _se[ran];
local n_r_R_6 = e(N);


gen hi_sd = (pool_sd > `median_pool_sd') if pool_sd != .;

xi: areg ideology i.ran*hi_sd, absorb(Unique_ID) cluster(state);

areg ideology ran if hi_sd == 1, absorb(Unique_ID) cluster(state);
local b_r_R_7 =  _b[ran];
local s_r_R_7 = _se[ran];
local n_r_R_7 = e(N);

areg ideology ran if hi_sd == 0, absorb(Unique_ID) cluster(state);
local b_r_R_8 =  _b[ran];
local s_r_R_8 = _se[ran];
local n_r_R_8 = e(N);


areg ideology Won_Primary if variation_Won_Primary == 1,                  absorb(Unique_ID) cluster(state);
local b_p_R_1 =  _b[Won_Primary];
local s_p_R_1 = _se[Won_Primary];
local n_p_R_1 = e(N);

areg ideology Won_Primary if variation_Won_Primary == 1 & open_seat == 1, absorb(Unique_ID) cluster(state);
local b_p_R_2 =  _b[Won_Primary];
local s_p_R_2 = _se[Won_Primary];
local n_p_R_2 = e(N);

areg ideology Won_Primary if variation_Won_Primary == 1 & safe == 1,      absorb(Unique_ID) cluster(state);
local b_p_R_3 =  _b[Won_Primary];
local s_p_R_3 = _se[Won_Primary];
local n_p_R_3 = e(N);

areg ideology Won_Primary if variation_Won_Primary == 1 & compet == 1,    absorb(Unique_ID) cluster(state);
local b_p_R_4 =  _b[Won_Primary];
local s_p_R_4 = _se[Won_Primary];
local n_p_R_4 = e(N);


areg ideology Won_General if variation_Won_General == 1,                  absorb(Unique_ID) cluster(state);
local b_g_R_1 =  _b[Won_General];
local s_g_R_1 = _se[Won_General];
local n_g_R_1 = e(N);

areg ideology Won_General if variation_Won_General == 1 & open_seat == 1, absorb(Unique_ID) cluster(state);
local b_g_R_2 =  _b[Won_General];
local s_g_R_2 = _se[Won_General];
local n_g_R_2 = e(N);

areg ideology Won_General if variation_Won_General == 1 & safe == 1,      absorb(Unique_ID) cluster(state);
local b_g_R_3 =  _b[Won_General];
local s_g_R_3 = _se[Won_General];
local n_g_R_3 = e(N);

areg ideology Won_General if variation_Won_General == 1 & compet == 1,    absorb(Unique_ID) cluster(state);
local b_g_R_4 =  _b[Won_General];
local s_g_R_4 = _se[Won_General];
local n_g_R_4 = e(N);



/* REGRESSIONS USING RANK OF IDEOLOGY AND DUMMY VERSION */

areg ideology_rank ran,                   absorb(Unique_ID) cluster(state);
local b_r_R_1_rank =  _b[ran];
local s_r_R_1_rank = _se[ran];
local n_r_R_1_rank = e(N);

areg ideology_rank ran if open_seat == 1, absorb(Unique_ID) cluster(state);
local b_r_R_2_rank =  _b[ran];
local s_r_R_2_rank = _se[ran];
local n_r_R_2_rank = e(N);

areg ideology_rank ran if safe == 1,      absorb(Unique_ID) cluster(state);
local b_r_R_3_rank =  _b[ran];
local s_r_R_3_rank = _se[ran];
local n_r_R_3_rank = e(N);

areg ideology_rank ran if compet == 1,    absorb(Unique_ID) cluster(state);
local b_r_R_4_rank =  _b[ran];
local s_r_R_4_rank = _se[ran];
local n_r_R_4_rank = e(N);


areg ideology_dummy ran,                   absorb(Unique_ID) cluster(state);
local b_r_R_1_dummy =  _b[ran];
local s_r_R_1_dummy = _se[ran];
local n_r_R_1_dummy = e(N);

areg ideology_dummy ran if open_seat == 1, absorb(Unique_ID) cluster(state);
local b_r_R_2_dummy =  _b[ran];
local s_r_R_2_dummy = _se[ran];
local n_r_R_2_dummy = e(N);

areg ideology_dummy ran if safe == 1,      absorb(Unique_ID) cluster(state);
local b_r_R_3_dummy =  _b[ran];
local s_r_R_3_dummy = _se[ran];
local n_r_R_3_dummy = e(N);

areg ideology_dummy ran if compet == 1,    absorb(Unique_ID) cluster(state);
local b_r_R_4_dummy =  _b[ran];
local s_r_R_4_dummy = _se[ran];
local n_r_R_4_dummy = e(N);


areg ideology_dummy2 ran,                   absorb(Unique_ID) cluster(state);
local b_r_R_1_dummy2 =  _b[ran];
local s_r_R_1_dummy2 = _se[ran];
local n_r_R_1_dummy2 = e(N);

areg ideology_dummy2 ran if open_seat == 1, absorb(Unique_ID) cluster(state);
local b_r_R_2_dummy2 =  _b[ran];
local s_r_R_2_dummy2 = _se[ran];
local n_r_R_2_dummy2 = e(N);

areg ideology_dummy2 ran if safe == 1,      absorb(Unique_ID) cluster(state);
local b_r_R_3_dummy2 =  _b[ran];
local s_r_R_3_dummy2 = _se[ran];
local n_r_R_3_dummy2 = e(N);

areg ideology_dummy2 ran if compet == 1,    absorb(Unique_ID) cluster(state);
local b_r_R_4_dummy2 =  _b[ran];
local s_r_R_4_dummy2 = _se[ran];
local n_r_R_4_dummy2 = e(N);


/* CHECK FOR TRENDING IN WINNERS VS. POOL */

gen t = year - 2005;
xi: areg ideology i.Won_Primary*t if variation_Won_Primary == 1,                  absorb(Unique_ID) cluster(state);
xi: areg ideology i.Won_General*t if variation_Won_General == 1,                  absorb(Unique_ID) cluster(state);



/* AUXILLARY COMPARISONS */

gen Won_Primary_safe   = Won_Primary * (safe == 1);
gen Won_Primary_not    = Won_Primary * (safe == 0);
gen Won_Primary_compet = Won_Primary * (compet == 1);

areg ideology Won_Primary_safe Won_Primary_not if variation_Won_Primary == 1,      absorb(Unique_ID) cluster(state);
test Won_Primary_safe = Won_Primary_not;

areg ideology Won_Primary_safe Won_Primary_compet if variation_Won_Primary == 1 & (safe == 1 | compet == 1),      absorb(Unique_ID) cluster(state);
test Won_Primary_safe = Won_Primary_compet;

gen Won_General_safe   = Won_General * (safe == 1);
gen Won_General_not    = Won_General * (safe == 0);
gen Won_General_compet = Won_General * (compet == 1);

areg ideology Won_General_safe Won_General_not if variation_Won_General == 1,      absorb(Unique_ID) cluster(state);
test Won_General_safe = Won_General_not;

areg ideology Won_General_safe Won_General_compet if variation_Won_General == 1 & (safe == 1 | compet == 1),      absorb(Unique_ID) cluster(state);
test Won_General_safe = Won_General_compet;



/* LOOK FOR STRATEGIC ENTRY: FEWER EXTREMISTS IN COMPETITIVE DISTRICTS? */

gen ran_verysafe = ran * (d_pres_vote_pct < 35);
areg ideology ran ran_verysafe, absorb(Unique_ID) cluster(state);
local b1 =  _b[ran];
local s1 = _se[ran];
local b2 =  _b[ran_verysafe];
local s2 = _se[ran_verysafe];

/* NUMBERS FOR TEXT */

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_25.tex, text replace;
  noisily display %5.3f `b1';
  log close;
};

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_26.tex, text replace;
  noisily display %5.3f `s1';
  log close;
};

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_27.tex, text replace;
  noisily display %5.3f `b2';
  log close;
};

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_28.tex, text replace;
  noisily display %5.3f `s2';
  log close;
};


/************************************************************/
/********** LATEX TABLE OF MAIN REGRESSION RESULTS **********/
/************************************************************/

quietly {;

  capture log close;
  log using ../output/tables/tbl_main_regressions_run_33.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf Within-pool comparisons: NP-Score of state legislators who run vs. those who do not.} ";
  noisily display "\label{tbl_main_regressions_run_33} ";
  noisily display "\begin{tabular}{lcccccc} ";
  noisily display "\toprule\toprule ";
  noisily display "& \multicolumn{3}{c}{Democrats} & \multicolumn{3}{c}{~Republicans} \\ [.05in] "; 
  noisily display "Sample                 & Coeff.  & Std. Error  &  \# Obs.  & ~~Coeff.  &  Std. Error  &  \# Obs.  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "All pools              & " %4.3f `b_r_D_1' " & (" %4.3f `s_r_D_1' ") & [" %3.0f `n_r_D_1' "] & ~~" %4.3f `b_r_R_1' " & (" %4.3f `s_r_R_1' ") & [" %3.0f `n_r_R_1' "] \\ [.01in] "; 
  noisily display "Open seats             & " %4.3f `b_r_D_2' " & (" %4.3f `s_r_D_2' ") & [" %3.0f `n_r_D_2' "] & ~~" %4.3f `b_r_R_2' " & (" %4.3f `s_r_R_2' ") & [" %3.0f `n_r_R_2' "] \\ [.01in] "; 
  noisily display "Safe districts         & " %4.3f `b_r_D_3' " & (" %4.3f `s_r_D_3' ") & [" %3.0f `n_r_D_3' "] & ~~" %4.3f `b_r_R_3' " & (" %4.3f `s_r_R_3' ") & [" %3.0f `n_r_R_3' "] \\ [.01in] ";
  noisily display "Competitive districts  & " %4.3f `b_r_D_4' " & (" %4.3f `s_r_D_4' ") & [" %3.0f `n_r_D_4' "] & ~~" %4.3f `b_r_R_4' " & (" %4.3f `s_r_R_4' ") & [" %3.0f `n_r_R_4' "] \\ [.01in] "; 

  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};



quietly {;

  capture log close;
  log using ../output/tables/tbl_main_regressions_run_33_more_heterogeneity.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf Within-Pool Comparisons: NP-Score of State Legislators Who Run vs. Those Who Do Not, Additional Results on Heterogeneity} ";
  noisily display "\label{tbl_main_regressions_run_33_more_heterogeneity} ";
  noisily display "\begin{tabular}{lcccccc} ";
  noisily display "\toprule\toprule ";
  noisily display "& \multicolumn{3}{c}{Democrats} & \multicolumn{3}{c}{~Republicans} \\ [.05in] "; 
  noisily display "Sample                 & Coeff.  & Std. Error  &  \# Obs.  & ~~Coeff.  &  Std. Error  &  \# Obs.  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "Large pools            & " %4.3f `b_r_D_5' " & (" %4.3f `s_r_D_5' ") & [" %3.0f `n_r_D_5' "] & ~~" %4.3f `b_r_R_5' " & (" %4.3f `s_r_R_5' ") & [" %3.0f `n_r_R_5' "] \\ [.01in] ";
  noisily display "Small pools            & " %4.3f `b_r_D_6' " & (" %4.3f `s_r_D_6' ") & [" %3.0f `n_r_D_6' "] & ~~" %4.3f `b_r_R_6' " & (" %4.3f `s_r_R_6' ") & [" %3.0f `n_r_R_6' "] \\ [.01in] "; 
  noisily display "High-variance pools    & " %4.3f `b_r_D_7' " & (" %4.3f `s_r_D_7' ") & [" %3.0f `n_r_D_7' "] & ~~" %4.3f `b_r_R_7' " & (" %4.3f `s_r_R_7' ") & [" %3.0f `n_r_R_7' "] \\ [.01in] ";
  noisily display "Low-variance pools     & " %4.3f `b_r_D_8' " & (" %4.3f `s_r_D_8' ") & [" %3.0f `n_r_D_8' "] & ~~" %4.3f `b_r_R_8' " & (" %4.3f `s_r_R_8' ") & [" %3.0f `n_r_R_8' "] \\ [.01in] "; 

  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};



quietly {;

  capture log close;
  log using ../output/tables/tbl_main_regressions_win_prim_genl_33.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf Within-pool comparisons: NP-Score of state legislators who win primary or general elections vs. others.} ";
  noisily display "\label{tbl_main_regressions_win_prim_genl_33} ";
  noisily display "\begin{tabular}{lcccccc} ";
  noisily display "\toprule\toprule ";
  noisily display "& \multicolumn{3}{c}{Democrats} & \multicolumn{3}{c}{~Republicans} \\ [.05in] "; 
  noisily display "Sample                 & Coeff.  & Std. Error  &  \# Obs.  & ~~Coeff.  &  Std. Error  &  \# Obs.  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "\multicolumn{7}{l}{\textit{Primary Election Winners vs. Others in Pool}} \\ [0.01in] ";
  noisily display "All pools              & " %4.3f `b_p_D_1' " & (" %4.3f `s_p_D_1' ") & [" %3.0f `n_p_D_1' "] & ~~" %4.3f `b_p_R_1' " & (" %4.3f `s_p_R_1' ") & [" %3.0f `n_p_R_1' "] \\ [.01in] "; 
  noisily display "Safe districts         & " %4.3f `b_p_D_3' " & (" %4.3f `s_p_D_3' ") & [" %3.0f `n_p_D_3' "] & ~~" %4.3f `b_p_R_3' " & (" %4.3f `s_p_R_3' ") & [" %3.0f `n_p_R_3' "] \\ [.01in] ";
  noisily display "Competitive districts  & " %4.3f `b_p_D_4' " & (" %4.3f `s_p_D_4' ") & [" %3.0f `n_p_D_4' "] & ~~" %4.3f `b_p_R_4' " & (" %4.3f `s_p_R_4' ") & [" %3.0f `n_p_R_4' "] \\ [.01in] "; 
  noisily display "\midrule ";
  noisily display "\multicolumn{7}{l}{\textit{General Election Winners vs. Others in Pool}} \\ [0.01in] ";
  noisily display "All pools              & " %4.3f `b_g_D_1' " & (" %4.3f `s_g_D_1' ") & [" %3.0f `n_g_D_1' "] & ~~" %4.3f `b_g_R_1' " & (" %4.3f `s_g_R_1' ") & [" %3.0f `n_g_R_1' "] \\ [.01in] "; 
  noisily display "Safe districts         & " %4.3f `b_g_D_3' " & (" %4.3f `s_g_D_3' ") & [" %3.0f `n_g_D_3' "] & ~~" %4.3f `b_g_R_3' " & (" %4.3f `s_g_R_3' ") & [" %3.0f `n_g_R_3' "] \\ [.01in] ";
  noisily display "Competitive districts  & " %4.3f `b_g_D_4' " & (" %4.3f `s_g_D_4' ") & [" %3.0f `n_g_D_4' "] & ~~" %4.3f `b_g_R_4' " & (" %4.3f `s_g_R_4' ") & [" %3.0f `n_g_R_4' "] \\ [.01in] "; 
  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};


quietly {;

  capture log close;
  log using ../output/tables/tbl_main_regressions_run_33_rank.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf Within-Pool Comparisons: NP-Score of State Legislators Who Run vs. Those Who Do Not, DV = Rank of Ideology} ";
  noisily display "\label{tbl_main_regressions_run_33_rank} ";
  noisily display "\begin{tabular}{lcccccc} ";
  noisily display "\toprule\toprule ";
  noisily display "& \multicolumn{3}{c}{Democrats} & \multicolumn{3}{c}{~Republicans} \\ [.05in] "; 
  noisily display "Sample                 & Coeff.  & Std. Error  &  \# Obs.  & ~~Coeff.  &  Std. Error  &  \# Obs.  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "All pools              & " %4.3f `b_r_D_1_rank' " & (" %4.3f `s_r_D_1_rank' ") & [" %3.0f `n_r_D_1_rank' "] & ~~" %4.3f `b_r_R_1_rank' " & (" %4.3f `s_r_R_1_rank' ") & [" %3.0f `n_r_R_1_rank' "] \\ [.01in] "; 
  noisily display "Open seats             & " %4.3f `b_r_D_2_rank' " & (" %4.3f `s_r_D_2_rank' ") & [" %3.0f `n_r_D_2_rank' "] & ~~" %4.3f `b_r_R_2_rank' " & (" %4.3f `s_r_R_2_rank' ") & [" %3.0f `n_r_R_2_rank' "] \\ [.01in] "; 
  noisily display "Safe districts         & " %4.3f `b_r_D_3_rank' " & (" %4.3f `s_r_D_3_rank' ") & [" %3.0f `n_r_D_3_rank' "] & ~~" %4.3f `b_r_R_3_rank' " & (" %4.3f `s_r_R_3_rank' ") & [" %3.0f `n_r_R_3_rank' "] \\ [.01in] ";
  noisily display "Competitive districts  & " %4.3f `b_r_D_4_rank' " & (" %4.3f `s_r_D_4_rank' ") & [" %3.0f `n_r_D_4_rank' "] & ~~" %4.3f `b_r_R_4_rank' " & (" %4.3f `s_r_R_4_rank' ") & [" %3.0f `n_r_R_4_rank' "] \\ [.01in] "; 
  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};



quietly {;

  capture log close;
  log using ../output/tables/tbl_main_regressions_run_33_dummy.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf Within-Pool Comparisons: NP-Score of State Legislators Who Run vs. Those Who Do Not, DV = Dummy of Ideology} ";
  noisily display "\label{tbl_main_regressions_run_33_dummy} ";
  noisily display "\begin{tabular}{lcccccc} ";
  noisily display "\toprule\toprule ";
  noisily display "& \multicolumn{3}{c}{Democrats} & \multicolumn{3}{c}{~Republicans} \\ [.05in] "; 
  noisily display "Sample                 & Coeff.  & Std. Error  &  \# Obs.  & ~~Coeff.  &  Std. Error  &  \# Obs.  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "All pools              & " %4.3f `b_r_D_1_dummy' " & (" %4.3f `s_r_D_1_dummy' ") & [" %3.0f `n_r_D_1_dummy' "] & ~~" %4.3f `b_r_R_1_dummy' " & (" %4.3f `s_r_R_1_dummy' ") & [" %3.0f `n_r_R_1_dummy' "] \\ [.01in] "; 
  noisily display "Open seats             & " %4.3f `b_r_D_2_dummy' " & (" %4.3f `s_r_D_2_dummy' ") & [" %3.0f `n_r_D_2_dummy' "] & ~~" %4.3f `b_r_R_2_dummy' " & (" %4.3f `s_r_R_2_dummy' ") & [" %3.0f `n_r_R_2_dummy' "] \\ [.01in] "; 
  noisily display "Safe districts         & " %4.3f `b_r_D_3_dummy' " & (" %4.3f `s_r_D_3_dummy' ") & [" %3.0f `n_r_D_3_dummy' "] & ~~" %4.3f `b_r_R_3_dummy' " & (" %4.3f `s_r_R_3_dummy' ") & [" %3.0f `n_r_R_3_dummy' "] \\ [.01in] ";
  noisily display "Competitive districts  & " %4.3f `b_r_D_4_dummy' " & (" %4.3f `s_r_D_4_dummy' ") & [" %3.0f `n_r_D_4_dummy' "] & ~~" %4.3f `b_r_R_4_dummy' " & (" %4.3f `s_r_R_4_dummy' ") & [" %3.0f `n_r_R_4_dummy' "] \\ [.01in] "; 
  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};

quietly {;

  capture log close;
  log using ../output/tables/tbl_main_regressions_run_33_dummy2.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf Within-Pool Comparisons: NP-Score of State Legislators Who Run vs. Those Who Do Not, DV = Dummy of Ideology Relative to Pool} ";
  noisily display "\label{tbl_main_regressions_run_33_dummy2} ";
  noisily display "\begin{tabular}{lcccccc} ";
  noisily display "\toprule\toprule ";
  noisily display "& \multicolumn{3}{c}{Democrats} & \multicolumn{3}{c}{~Republicans} \\ [.05in] "; 
  noisily display "Sample                 & Coeff.  & Std. Error  &  \# Obs.  & ~~Coeff.  &  Std. Error  &  \# Obs.  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "All pools              & " %4.3f `b_r_D_1_dummy2' " & (" %4.3f `s_r_D_1_dummy2' ") & [" %3.0f `n_r_D_1_dummy2' "] & ~~" %4.3f `b_r_R_1_dummy2' " & (" %4.3f `s_r_R_1_dummy2' ") & [" %3.0f `n_r_R_1_dummy2' "] \\ [.01in] "; 
  noisily display "Open seats             & " %4.3f `b_r_D_2_dummy2' " & (" %4.3f `s_r_D_2_dummy2' ") & [" %3.0f `n_r_D_2_dummy2' "] & ~~" %4.3f `b_r_R_2_dummy2' " & (" %4.3f `s_r_R_2_dummy2' ") & [" %3.0f `n_r_R_2_dummy2' "] \\ [.01in] "; 
  noisily display "Safe districts         & " %4.3f `b_r_D_3_dummy2' " & (" %4.3f `s_r_D_3_dummy2' ") & [" %3.0f `n_r_D_3_dummy2' "] & ~~" %4.3f `b_r_R_3_dummy2' " & (" %4.3f `s_r_R_3_dummy2' ") & [" %3.0f `n_r_R_3_dummy2' "] \\ [.01in] ";
  noisily display "Competitive districts  & " %4.3f `b_r_D_4_dummy2' " & (" %4.3f `s_r_D_4_dummy2' ") & [" %3.0f `n_r_D_4_dummy2' "] & ~~" %4.3f `b_r_R_4_dummy2' " & (" %4.3f `s_r_R_4_dummy2' ") & [" %3.0f `n_r_R_4_dummy2' "] \\ [.01in] "; 
  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};



/*******************************************************/
/********** BACK-OF-THE-ENVELOPE CALCULATIONS **********/
/*******************************************************/

local last_early = 2002;
local first_late = 2010;

use ../pools_data/merged_data_33_dems, clear;
append using ../pools_data/merged_data_33_reps;
rename Year     year;
rename Ran      ran;
rename District dist;
rename Ideology ideology;
drop type;
gen     type = "G" if Special == 0;
replace type = "S" if Special == 1;
merge m:1 state dist year type using ../other_data/cong_incumbency;
drop if _merge == 2;
drop _merge;
merge m:1 state dist year type using ../other_data/pres_vote_to_use;
drop if _merge == 2;
drop _merge;
rename Legislator_Party party;

gen byte open_seat = (inc_D == 0 & inc_R == 0);
gen byte safe   = (party == "D" &  d_pres_vote_pct > 55.0 & d_pres_vote_pct != .) | (party == "R" & d_pres_vote_pct < 45.0 & d_pres_vote_pct != .);
gen byte compet = (d_pres_vote_pct >= 45.0 & d_pres_vote_pct <= 55.0) if d_pres_vote_pct != .;

drop if Special == 1;
drop if safe == .;
drop if ideology == .;

save tmp1, replace;


use tmp1, clear;

egen x = mean(ideology), by(Unique_ID party);
gen ideo_diff = ideology - x;

sum ideo_diff if safe == 1 & Won_General == 1 & party == "R";
local r_s_w = r(mean);

sum ideo_diff if safe == 1 & Won_General == 1 & party == "D";
local d_s_w = r(mean);

local gap_s_w = `r_s_w' - `d_s_w';

sum ideo_diff if safe == 0 & Won_General == 1 & party == "R";
local r_n_w = r(mean);

sum ideo_diff if safe == 0 & Won_General == 1 & party == "D";
local d_n_w = r(mean);

local gap_n_w = `r_n_w' - `d_n_w';

sort year state dist safe;

sum safe if !(year == year[_n-1] & state == state[_n-1] & dist == dist[_n-1]) & year <= `last_early';
local safe_0 = r(mean);

sum safe if !(year == year[_n-1] & state == state[_n-1] & dist == dist[_n-1]) & year >= `first_late';
local safe_1 = r(mean);

display `gap_s_w';
display `gap_n_w';
display (`safe_1' - `safe_0') * (`gap_s_w' - `gap_n_w');


use tmp1, clear;

collapse ideology, by(Unique_ID party year);

sum ideology if party == "R" & year <= `last_early';
local r_0 = r(mean);

sum ideology if party == "D" & year <= `last_early';
local d_0 = r(mean);

sum ideology if party == "R" & year >= `first_late';
local r_1 = r(mean);

sum ideology if party == "D" & year >= `first_late';
local d_1 = r(mean);

local gap_pool_0 = `r_0' - `d_0';
local gap_pool_1 = `r_1' - `d_1'; 

display `gap_pool_1';
display `gap_pool_0';
display `gap_pool_1' - `gap_pool_0';


use tmp1, clear;

keep if Won_General == 1;

sum ideology if party == "R" & year <= `last_early';
local r_w_0 = r(mean);

sum ideology if party == "D" & year <= `last_early';
local d_w_0 = r(mean);

sum ideology if party == "R" & year >= `first_late';
local r_w_1 = r(mean);

sum ideology if party == "D" & year >= `first_late';
local d_w_1 = r(mean);

local gap_w_0 = `r_w_0' - `d_w_0';
local gap_w_1 = `r_w_1' - `d_w_1'; 

display `gap_w_1';
display `gap_w_0';

quietly {;
  noisily display "Increase in overall gap between R and D winners between 1996-`last_early' and `first_late'-2016 = "  %5.3f `gap_w_1' - `gap_w_0';
  noisily display "";
  noisily display "Increase in average gap between R and D pools between 1996-`last_early' and `first_late'-2016 = "  %5.3f `gap_pool_1' - `gap_pool_0';
  noisily display "";
  noisily display "Increase in gap between R and D winners due to increasing proportion of safe districts ";
  noisily display "(together with fact that winners are noticeably more extreme than random draw from pool in safe ";
  noisily display "districts but much less so in competitive districts) = "  %5.3f (`safe_1' - `safe_0') * (`gap_s_w' - `gap_n_w');
};

/* NUMBERS FOR TEXT */

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_29.tex, text replace;
  noisily display %5.3f `gap_w_1' - `gap_w_0';
  log close;
};

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_30.tex, text replace;
  noisily display %5.3f `gap_pool_1' - `gap_pool_0';
  log close;
};

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_31.tex, text replace;
  noisily display %4.1f 100 * (`gap_pool_1' - `gap_pool_0')/(`gap_w_1' - `gap_w_0');
  log close;
};

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_32.tex, text replace;
  noisily display %5.3f (`safe_1' - `safe_0') * (`gap_s_w' - `gap_n_w');
  log close;
};

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_33.tex, text replace;
  noisily display %4.1f 100 * ((`safe_1' - `safe_0') * (`gap_s_w' - `gap_n_w'))/(`gap_w_1' - `gap_w_0');
  log close;
};




erase tmp1.dta;

