
******* binscatters of size of candidate pool 

use ../pools_data/merged_data_33_dems, clear
append using ../pools_data/merged_data_33_reps
rename Year     year
rename Ran      ran
rename District dist
rename Ideology ideology
drop type
gen     type = "G" if Special == 0
replace type = "S" if Special == 1
merge m:1 state dist year type using ../other_data/cong_incumbency
drop if _merge == 2
drop _merge
merge m:1 state dist year type using ../other_data/pres_vote_to_use
drop if _merge == 2

egen x = count(year), by(Unique_ID Legislator)
sort Unique_ID Legislator
drop if x > 1 & Legislator == Legislator[_n-1]
drop x

replace year = year + 1 if mod(year, 2) == 1
drop if mod(year, 2) == 1

gen n_D = 1                 if Legislator_Party == "D"
gen n_R = 1                 if Legislator_Party == "R"
gen ideology_D = ideology   if Legislator_Party == "D"
gen ideology_R = ideology   if Legislator_Party == "R"
gen ran_D = ran             if Legislator_Party == "D"
gen ran_R = ran             if Legislator_Party == "R"

order state dist year type Legislator_Party Unique *_D *_R

collapse (sum) n_D n_R ///
         (mean) mean_ideo_D = ideology_D  mean_ideo_R = ideology_R  d_pres_vote_pct  ///
         (sd)   sd_ideo_D   = ideology_D  sd_ideo_R   = ideology_R  ///
         (max) someone_ran_D = ran_D  someone_ran_R = ran_R  ///
 , by(state dist year type)

gen dpv = d_pres_vote_pct/100

binscatter n_D dpv, linetype(qfit) scale(1.4) lc(gs0) colors(gs0) ///
	yscale(range(-3 21)) ylabel(0(5)20) ///
	xscale(range(.20 .90)) xlabel(.20 .30 .40 .50 .60 .70 .80 .90) ///
	xtitle("Democratic Presidential Vote Share (DPV)")  ytitle("# State Legislators in Pool") 
graph export "../output/figures/pool_size_D_33.pdf", replace

binscatter n_R dpv, linetype(qfit) scale(1.4) lc(gs0) colors(gs0) ///
	yscale(range(-3 21)) ylabel(0(5)20) ///
	xscale(range(.20 .90)) xlabel(.20 .30 .40 .50 .60 .70 .80 .90) ///
	xtitle("Democratic Presidential Vote Share (DPV)")  ytitle("# of State Legislators in Pool") 
graph export "../output/figures/pool_size_R_33.pdf", replace


sort state year
merge m:1 state year using ../other_data/num_state_legs_and_cong_dists
keep if _merge == 3

gen r = num_state_legislators/num_cong_dist
gen n_D_norm = n_D/r
gen n_R_norm = n_R/r

binscatter n_D_norm dpv, linetype(qfit) scale(1.4) lc(gs0) colors(gs0) ///
	yscale(range(-.15 1.3)) ylabel(0(.2)1.2) ///
	xscale(range(.20 .90)) xlabel(.20 .30 .40 .50 .60 .70 .80 .90) ///
	xtitle("Democratic Presidential Vote Share (DPV)")  ytitle("State Legs in Pool, Normalized") 
graph export "../output/figures/pool_size_D_norm_33.pdf", replace


binscatter n_R_norm dpv, linetype(qfit) scale(1.4) lc(gs0) colors(gs0) ///
	yscale(range(-.15 1.3)) ylabel(0(.2)1.2) ///
	xscale(range(.20 .90)) xlabel(.20 .30 .40 .50 .60 .70 .80 .90) ///
	xtitle("Democratic Presidential Vote Share (DPV)")  ytitle("State Legs in Pool, Normalized") 
graph export "../output/figures/pool_size_R_norm_33.pdf", replace



binscatter mean_ideo_D dpv, linetype(qfit) scale(1.4) lc(gs0) colors(gs0) ///
	ytitle("Mean NP-Score") yscale(range(-1.5 -.3)) ylabel(-1.5 -1 -.5) ///
	xscale(range(.20 .90)) xlabel(.20 .30 .40 .50 .60 .70 .80 .90) ///
	xtitle("Democratic Presidential Vote Share (DPV)")
graph export "../output/figures/ideo_mean_D_vs_dem_pres_share_33.pdf", replace



binscatter mean_ideo_R dpv, linetype(qfit)scale(1.4) lc(gs0) colors(gs0) ///
	ytitle("Mean NP-Score") yscale(range(.3 1.5)) ylabel(.5 1 1.5) ///
	xscale(range(.20 .90)) xlabel(.20 .30 .40 .50 .60 .70 .80 .90) ///
	xtitle("Democratic Presidential Vote Share (DPV)")
graph export "../output/figures/ideo_mean_R_vs_dem_pres_share_33.pdf", replace



**** plots of ideology of pools vs. who runs across partisanship and over time

use ../pools_data/merged_data_33_dems, clear
keep if Contested == 1
rename Year     year
rename Ran      ran
rename District dist
rename Ideology ideology
drop type
gen     type = "G" if Special == 0
replace type = "S" if Special == 1
merge m:1 state dist year type using ../other_data/cong_incumbency
drop if _merge == 2
drop _merge
merge m:1 state dist year type using ../other_data/pres_vote_to_use
drop if _merge == 2

egen x = count(year), by(Unique_ID Legislator)
sort Unique_ID Legislator
drop if x > 1 & Legislator == Legislator[_n-1]
drop x

/*
egen x = pctile(ideology), p(1)
drop if ideology < x
drop x
egen x = pctile(ideology), p(99)
drop if ideology > x
drop x
*/


replace year = year + 1 if mod(year, 2) == 1


egen x = mean(ideology) if ran == 0, by(Unique_ID)
egen ideo_nonrunner_mean = max(x), by(Unique_ID)
gen ideo_diff = ideology - ideo_nonrunner_mean
drop x

egen ideo_pool_mean = mean(ideology), by(Unique_ID)
gen ideo_diff_2 = ideology - ideo_pool_mean

gen dpv = d_pres_vote_pct/100


binscatter ideo_diff dpv if ran == 1, linetype(qfit) lc(gs0) colors(gs0) yline(0) ///
	ytitle("Difference in NP-Score") yscale(range(-.3 .3)) ylabel(-.3 -.2 -.1 0 .1 .2 .3) ///
	xscale(range(.20 .90)) xlabel(.20 .30 .40 .50 .60 .70 .80 .90) xtitle("Democratic Presidential Vote Share (DPV)") ///
	scale(1.4) genxq(xbin_dvp) 
graph export "../output/figures/ideo_diff_D_vs_dem_pres_share_33.pdf", replace


binscatter ideo_diff year if ran == 1, linetype(qfit) lc(gs0) colors(gs0) yline(0) ///
	ytitle("Difference in NP-Score") yscale(range(-.2 .2)) ylabel(-.2 -.1 0 .1 .2) ///
	xtitle("Year") xlabel(1996 2000 2004 2008 2012 2016) ///
	scale(1.4) genxq(xbin_year) 
graph export "../output/figures/ideo_diff_D_vs_year_33.pdf", replace



/*
binscatter ideology dpv, by(ran) linetype(qfit) /// 
	ytitle("NP-Score") yscale(range(-1.51 0)) ylabel(-1.5 -1 -.5 0) lc(gs10 gs1) colors(gs10 gs1)  ///
	xscale(range(.20 .90)) xlabel(.20 .30 .40 .50 .60 .70 .80 .90) xtitle("Democratic Presidential Vote Share (dpv") ///
	scale(1.4) legend(label(2 "Ran") label(1 "Did Not Run"))
* gr_edit .plotregion1.plot3.style.editstyle line(pattern(dash)) editcopy
* gr_edit .plotregion1.plot4.style.editstyle line(pattern(solid)) editcopy
* gr_edit .plotregion1.plot3.style.editstyle line(color(gs10)) editcopy
* gr_edit .plotregion1.plot2.style.editstyle marker(size(vsmall)) editcopy
* gr_edit .plotregion1.plot1.style.editstyle marker(size(vsmall)) editcopy
graph export "../output/figures/ideology_D_vs_dem_pres_share_33.pdf", replace

binscatter ideology year, by(ran) linetype(qfit) /// 
	xtitle("Year") xlabel(1996 2000 2004 2008 2012 2016) ///
	ytitle("NP-Score") yscale(range(-.50 -1.11)) ylabel(-1 -.75 -.5) ///
	lc(gs10 gs1) colors(gs10 gs1) scale(1.4) legend(label(2 "Ran") label(1 "Did Not Run")) nquantiles(11) 
graph export "../output/figures/ideology_D_vs_year_33.pdf", replace
*/



use ../pools_data/merged_data_33_reps, clear
keep if Contested == 1
rename Year     year
rename Ran      ran
rename District dist
rename Ideology ideology
drop type
gen     type = "G" if Special == 0
replace type = "S" if Special == 1
merge m:1 state dist year type using ../other_data/cong_incumbency
drop if _merge == 2
drop _merge
merge m:1 state dist year type using ../other_data/pres_vote_to_use
drop if _merge == 2

egen x = count(year), by(Unique_ID Legislator)
sort Unique_ID Legislator
drop if x > 1 & Legislator == Legislator[_n-1]
drop x


egen x = count(year), by(Unique_ID Legislator)
sort Unique_ID Legislator
drop if x > 1 & Legislator == Legislator[_n-1]
drop x

replace year = year + 1 if mod(year, 2) == 1

egen x = mean(ideology) if ran == 0, by(Unique_ID)
egen ideo_nonrunner_mean = max(x), by(Unique_ID)
gen ideo_diff = ideology - ideo_nonrunner_mean
drop x

egen ideo_pool_mean = mean(ideology), by(Unique_ID)
gen ideo_diff_2 = ideology - ideo_pool_mean

gen dpv = d_pres_vote_pct/100

binscatter ideo_diff dpv if ran == 1, linetype(qfit) lc(gs0) colors(gs0) yline(0) ///
	ytitle("Difference in NP-Score") yscale(range(-.3 .3)) ylabel(-.3 -.2 -.1 0 .1 .2 .3) ///
	xscale(range(.20 .90)) xlabel(.20 .30 .40 .50 .60 .70 .80 .90) xtitle("Democratic Presidential Vote Share (DPV)")  ///
	scale(1.4) genxq(xbin_dvp) 
graph export "../output/figures/ideo_diff_R_vs_dem_pres_share_33.pdf", replace


binscatter ideo_diff year if ran == 1, linetype(qfit) lc(gs0) colors(gs0) yline(0) ///
	ytitle("Difference in NP-Score") yscale(range(-.2 .2)) ylabel(-.2 -.1 0 .1 .2) ///
	xtitle("Year") xlabel(1996 2000 2004 2008 2012 2016) xtitle("Year") ///
	scale(1.4) genxq(xbin_year) 
graph export "../output/figures/ideo_diff_R_vs_year_33.pdf", replace


/*
binscatter ideology dpv, by(ran) linetype(qfit) xtitle("Democratic Presidential Vote Share (DPV)") ///
	ytitle("NP-Score") yscale(range(0 1.51)) ylabel(0 .5 1 1.5) lc(gs10 gs1) colors(gs10 gs1)  ///
	xscale(range(.20 .90)) xlabel(.20 .30 .40 .50 .60 .70 .80 .90) ///
	scale(1.4) legend(label(2 "Ran") label(1 "Did Not Run"))
* gr_edit .plotregion1.plot3.style.editstyle line(pattern(dash)) editcopy
* gr_edit .plotregion1.plot4.style.editstyle line(pattern(solid)) editcopy
* gr_edit .plotregion1.plot3.style.editstyle line(color(gs10)) editcopy
* gr_edit .plotregion1.plot2.style.editstyle marker(size(vsmall)) editcopy
* gr_edit .plotregion1.plot1.style.editstyle marker(size(vsmall)) editcopy
graph export "../output/figures/ideology_R_vs_dem_pres_share_33.pdf", replace


binscatter ideology year, by(ran) linetype(qfit) /// 
	xtitle("Year") xlabel(1996 2000 2004 2008 2012 2016) ///
	ytitle("NP-Score") yscale(range(.50 1.11)) ylabel(.5 .75 1) ///
	lc(gs10 gs1) colors(gs10 gs1) scale(1.4) legend(label(2 "Ran") label(1 "Did Not Run")) nquantiles(11) 
graph export "../output/figures/ideology_R_vs_year_33.pdf", replace
*/


***** party by year mean ideology graph

use ../pools_data/merged_data_33_dems, clear
rename Year     year
rename Ran      ran
rename District dist
rename Ideology ideology
drop type
gen     type = "G" if Special == 0
replace type = "S" if Special == 1
merge m:1 state dist year type using ../other_data/cong_incumbency
drop if _merge == 2
drop _merge
merge m:1 state dist year type using ../other_data/pres_vote_to_use
drop if _merge == 2

replace year = year + 1 if mod(year, 2) == 1
drop if mod(year, 2) == 1

egen x = count(year), by(Unique_ID Legislator)
sort Unique_ID Legislator
drop if x > 1 & Legislator == Legislator[_n-1]
drop x

/*
egen x = pctile(ideology), p(1)
drop if ideology < x
drop x
egen x = pctile(ideology), p(99)
drop if ideology > x
drop x
*/

sort year

sum ideology
local N_nationwide_D    = r(N)
local mean_nationwide_D = r(mean)
local sd_nationwide_D   = r(sd)

gen ideology_550 = ideology if d_pres_vote_pct > 55.0
gen ideology_575 = ideology if d_pres_vote_pct > 57.5
gen ideology_600 = ideology if d_pres_vote_pct > 60.0
gen ideology_450_550 = ideology if d_pres_vote_pct >= 45.0 & d_pres_vote_pct <= 55.0
collapse  mean_ideo_pool_D = ideology  mean_ideo_pool_550_D = ideology_550  mean_ideo_pool_575_D = ideology_575  mean_ideo_pool_600_D = ideology_600 mean_ideo_pool_450_550_D = ideology_450_550, by(Unique_ID state year)


replace Unique_ID = reverse(substr(reverse(Unique_ID), 3, .))
sort Unique_ID
save tmp1, replace

sum mean_ideo_pool_D
local N_pool_D = r(N)
local mean_pool_D = r(mean)

sum mean_ideo_pool_550_D
local N_pool_550_D = r(N)
local mean_pool_550_D = r(mean)

sum mean_ideo_pool_575_D
local N_pool_575_D = r(N)
local mean_pool_575_D = r(mean)

sum mean_ideo_pool_600_D
local N_pool_600_D = r(N)
local mean_pool_600_D = r(mean)

sum mean_ideo_pool_450_550_D
local N_pool_450_550_D = r(N)
local mean_pool_450_550_D = r(mean)

use ../pools_data/merged_data_33_reps, clear
rename Year     year
rename Ran      ran
rename District dist
rename Ideology ideology
drop type
gen     type = "G" if Special == 0
replace type = "S" if Special == 1
merge m:1 state dist year type using ../other_data/cong_incumbency
drop if _merge == 2
drop _merge
merge m:1 state dist year type using ../other_data/pres_vote_to_use
drop if _merge == 2

replace year = year + 1 if mod(year, 2) == 1
drop if mod(year, 2) == 1

egen x = count(year), by(Unique_ID Legislator)
sort Unique_ID Legislator
drop if x > 1 & Legislator == Legislator[_n-1]
drop x

/*
egen x = pctile(ideology), p(1)
drop if ideology < x
drop x
egen x = pctile(ideology), p(99)
drop if ideology > x
drop x
*/

sort year

sum ideology
local N_nationwide_R    = r(N)
local mean_nationwide_R = r(mean)
local sd_nationwide_R   = r(sd)

gen ideology_550 = ideology if 100 - d_pres_vote_pct > 55.0
gen ideology_575 = ideology if 100 - d_pres_vote_pct > 57.5
gen ideology_600 = ideology if 100 - d_pres_vote_pct > 60.0
gen ideology_450_550 = ideology if d_pres_vote_pct >= 45.0 & d_pres_vote_pct <= 55.0

collapse  mean_ideo_pool_R = ideology  mean_ideo_pool_550_R = ideology_550  mean_ideo_pool_575_R = ideology_575  mean_ideo_pool_600_R = ideology_600 mean_ideo_pool_450_550_R = ideology_450_550, by(Unique_ID state year)

sum mean_ideo_pool_R
local N_pool_R = r(N)
local mean_pool_R = r(mean)

sum mean_ideo_pool_550_R
local N_pool_550_R = r(N)
local mean_pool_550_R = r(mean)

sum mean_ideo_pool_575_R
local N_pool_575_R = r(N)
local mean_pool_575_R = r(mean)

sum mean_ideo_pool_600_R
local N_pool_600_R = r(N)
local mean_pool_600_R = r(mean)

sum mean_ideo_pool_450_550_R
local N_pool_450_550_R = r(N)
local mean_pool_450_550_R = r(mean)

replace Unique_ID = reverse(substr(reverse(Unique_ID), 3, .))
sort Unique_ID
merge Unique_ID using tmp1, update
sort Unique_ID
save tmp1, replace
sleep 2000

collapse (mean) mean_ideo_*, by(year)
save tmp1, replace

use ../pools_data/merged_data_33_dems, clear
rename Year     year
rename Ran      ran
rename District dist
rename Ideology ideology
drop type
gen     type = "G" if Special == 0
replace type = "S" if Special == 1
merge m:1 state dist year type using ../other_data/cong_incumbency
drop if _merge == 2
drop _merge
merge m:1 state dist year type using ../other_data/pres_vote_to_use
drop if _merge == 2

egen x = count(year), by(Unique_ID Legislator)
sort Unique_ID Legislator
drop if x > 1 & Legislator == Legislator[_n-1]
drop x

replace year = year + 1 if mod(year, 2) == 1

sort state year Legislator dist
gen ideology_norepeats = ideology if !(state == state[_n-1] & year == year[_n-1] & Legislator == Legislator[_n-1])
collapse (mean) mean_ideo_overall_D = ideology_norepeats, by(year)
merge year using tmp1
drop _merge
sort year
save tmp1, replace

use ../pools_data/merged_data_33_reps, clear
rename Year     year
rename Ran      ran
rename District dist
rename Ideology ideology
drop type
gen     type = "G" if Special == 0
replace type = "S" if Special == 1
merge m:1 state dist year type using ../other_data/cong_incumbency
drop if _merge == 2
drop _merge
merge m:1 state dist year type using ../other_data/pres_vote_to_use
drop if _merge == 2

egen x = count(year), by(Unique_ID Legislator)
sort Unique_ID Legislator
drop if x > 1 & Legislator == Legislator[_n-1]
drop x

replace year = year + 1 if mod(year, 2) == 1

sort state year Legislator dist
gen ideology_norepeats = ideology if !(state == state[_n-1] & year == year[_n-1] & Legislator == Legislator[_n-1])
collapse (mean) mean_ideo_overall_R = ideology_norepeats, by(year)
merge year using tmp1
drop _merge
sort year
save tmp1, replace


scatter mean_ideo_overall_D mean_ideo_pool_550_D mean_ideo_pool_450_550_D mean_ideo_pool_D year, ///
  plotregion(style(none)) graphregion(fcolor(white) lcolor(white)) ///
  c(l l l l) mcolor(gs12 gs6 gs8 gs0) lcolor(gs12 gs6 gs8 gs0) ///
  legend(off) yscale(range(-.70 -1.25)) ylabel(-.75 -1 -1.25) ///
  xlabel(1996 2002 2008 2014) xtitle("") ytitle(Mean ideology) ///
  text(-.80 2014 "National Average", color(gs12) size(3)) ///
  text(-1.22 2002 "Average of Pools in Safe Districts", color(gs6) size(3)) ///
  text(-1.04 2010 "Average of Pools in Competitive Districts", color(gs8) size(3)) ///
  text(-.88 2005 "Average of Pools", color(gs0) size(3)) scale(1.4)
 graph export "../output/figures/pool_ideology_D_33.pdf", replace


scatter mean_ideo_overall_R mean_ideo_pool_550_R mean_ideo_pool_450_550_R mean_ideo_pool_R year, ///
  plotregion(style(none)) graphregion(fcolor(white) lcolor(white)) ///
  c(l l l l) mcolor(gs12 gs6 gs8 gs0) lcolor(gs12 gs6 gs8 gs0) ///
  legend(off) yscale(range(.50 1.05)) ylabel(.5 .75 1) ///
  xlabel(1996 2002 2008 2014) xtitle("") ytitle(Mean ideology) ///
  text(.79 2006.2 "National Average", color(gs12) size(3)) ///
  text(0.95 2003 "Average of Pools in Safe Districts", color(gs6) size(3)) ///
  text(.55 2009 "Average of Pools in Competitive Districts", color(gs8) size(3)) ///
  text(.67 2007 "Average of Pools", color(gs0) size(3)) scale(1.4)
 graph export "../output/figures/pool_ideology_R_33.pdf", replace
  
  
erase tmp1.dta  
  
