
#delimit ;

set linesize 250;



/* TO COMPUTE NUMBERS REGARDING SITTING AND FORMER STATE LEGISLATORS */

use ../other_data/cong_primaries_1996_2016, clear;
drop if year == 2017;
drop if inc > 0;


/* PERCENT OF RUNNERS WHO ARE SITTING OR FORMER STATE LEGISLATORS */

sum state_leg;
local m = 100 * r(mean);

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_1.tex, text replace;
  noisily display %4.1f `m';
  log close;
};

/* PERCENT OF PRIMARY WINNERS WHO ARE SITTING OR FORMER STATE LEGISLATORS */

sum state_leg if w_p == 1;
local m = 100 * r(mean);

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_2.tex, text replace;
  noisily display %4.1f `m';
  log close;
};

/* PERCENT OF GENERAL WINNERS WHO ARE SITTING OR FORMER STATE LEGISLATORS */

sum state_leg if w_g == 1;
local m = 100 * r(mean);

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_3.tex, text replace;
  noisily display %4.1f `m';
  log close;
};


/* TO COMPUTER FRACTION OF STATE LEGISLATORS WHO DO NOT IN THE POOL WITH LARGEST OVERLAP */

use          ../pools_data/merged_data_33_dems, clear;
append using ../pools_data/merged_data_33_reps;
egen ran_all_obs = max(Ran), by(State Legislator Year Special);
keep if ran_all_obs == 1;
egen x = max(SLD_Prop), by(State Legislator Year Special);
gen ran_not_largest = (Ran == 1 & SLD_Prop < x - .00001);
collapse (max) ran_not_largest, by(State Legislator Year Special);

sum ran_not_largest;
local m = 100 * r(mean);

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_4.tex, text replace;
  noisily display %4.1f `m';
  log close;
};

count if ran_not_largest == 1;
local m = r(N);

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_5.tex, text replace;
  noisily display %2.0f `m';
  log close;
};


/* TO COMPUTE FRACTION OF STATE LEGISLATORS IN MULTIPLE POOLS */
 
use          ../pools_data/merged_data_33_dems, clear;
append using ../pools_data/merged_data_33_reps;
gen x = 1;
collapse (sum) x, by(State Legislator Year Special);
gen xx = (x > 1);

sum xx;
local m = 100 * r(mean);

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_6.tex, text replace;
  noisily display %4.1f `m';
  log close;
};


/* TO COMPUTE NUMBERS REGARDING SITTING LEGISLATORS ONLY */

use          ../pools_data/merged_data_33_dems, clear;
append using ../pools_data/merged_data_33_reps;
rename Year year;
gen is_in_data = 1;
collapse (sum) is_in_data, by(state year);
save tmp0, replace;

use          ../pools_data/merged_data_33_dems, clear;
append using ../pools_data/merged_data_33_reps;
keep if Ran == 1;
rename Year year;
rename Dist dist;
rename Legislator name;
rename Legislator_Party party;
drop type;
gen     type = "G" if Special == 0;
replace type = "S" if Special == 1;
gen x = 1;
keep state year office dist type name party x;
save tmp1, replace;

use ../other_data/cong_primaries_1996_2016, clear;
drop state_leg;
merge m:1 state year office dist type party name using tmp1;
drop _merge;
merge m:1 state year using tmp0;
gen state_leg = (x == 1);
keep if inc == 0;

drop if is_in_data == .;

egen t = sum(vote_p), by(state year office dist type party);
gen vote_p_share = vote_p/t;


/* PERCENT OF RUNNERS WHO ARE SITTING STATE LEGISLATORS */

sum state_leg;
local m = 100 * r(mean);

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_7.tex, text replace;
  noisily display %4.1f `m';
  log close;
};


/* PERCENT OF PRIMARY WINNERS WHO ARE SITTING STATE LEGISLATORS */

sum state_leg if w_p == 1;
local m = 100 * r(mean);

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_8.tex, text replace;
  noisily display %4.1f `m';
  log close;
};

/* PERCENT OF GENERAL WINNERS WHO ARE SITTING STATE LEGISLATORS */

sum state_leg if w_g == 1;
local m = 100 * r(mean);

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_9.tex, text replace;
  noisily display %4.1f `m';
  log close;
};


/* NUMBER OF POOLS */

use          ../pools_data/merged_data_33_dems, clear;
append using ../pools_data/merged_data_33_reps;

gen x = 1;
collapse x, by(State District Year Special Legislator_Party);
gen xx = State + " " + string(District) + " " + string(Year) + " " + string(Special);
fillin xx Legislator_Party;

local m = _N;

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_10.tex, text replace;
  noisily display %4.0f `m';
  log close;
};


/* NUMBER OF UNIQUE INDIVIDUAL STATE LEGISLATORS */

use          ../pools_data/merged_data_33_dems, clear;
append using ../pools_data/merged_data_33_reps;

gen x = 1;
collapse x, by(State Legislator);

local m = _N;

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_11.tex, text replace;
  noisily display %5.0f `m';
  log close;
};



/* PERCENT OF DISTRICTS THAT ARE COMPETITIVE OVERALL */

use          ../pools_data/merged_data_33_dems, clear;
append using ../pools_data/merged_data_33_reps;
gen x = 1;
rename Year year;
rename Dist dist;
drop type;
gen type = "G";
replace type = "S" if Special == 1;
collapse x, by(state year dist type);
save tmp1, replace;

use ../other_data/pres_vote_to_use, clear;
merge m:1 state year dist type using tmp1;
keep if _merge == 3;

gen n_SR = 1 if d_pres_vote_pct < 45.0;
gen n_SD = 1 if d_pres_vote_pct > 55.0;
gen n_C  = 1 if n_SR == . & n_SD == .;
replace n_C = 0 if n_C == .;

/* PERCENT OF DISTRICTS THAT ARE COMPETITIVE */

sum n_C;
local m = 100 * r(mean);

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_12.tex, text replace;
  noisily display %4.1f `m';
  log close;
};


/* PERCENT OF DISTRICTS THAT ARE COMPETITIVE IN 1996 */

sum n_C if year == 1996;
local m = 100 * r(mean);

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_13.tex, text replace;
  noisily display %4.1f `m';
  log close;
};


/* PERCENT OF DISTRICTS THAT ARE COMPETITIVE IN 2016 */

sum n_C if year == 2016;
local m = 100 * r(mean);

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_14.tex, text replace;
  noisily display %4.1f `m';
  log close;
};

/* INCREASE IN NUMBER OF SAFE REPUBLICAN VERSUS DEMOCRATIC DISTRICTS */

sum n_SD if year == 1996;
local d1996 = r(N);

sum n_SR if year == 1996;
local r1996 = r(N);

sum n_SD if year == 2016;
local d2016 = r(N);

sum n_SR if year == 2016;
local r2016 = r(N);

display `r2016' - `r1996';
display `d2016' - `d1996';

/* NUMBER AND FRACTION OF POOLS THAT ARE EMPTY (OF STATE LEGISLATORS) FOR EACH PARTY */

use          ../pools_data/merged_data_33_dems, clear;
append using ../pools_data/merged_data_33_reps;

gen x = 1;
collapse x, by(State District Year Special Legislator_Party);
gen xx = State + " " + string(District) + " " + string(Year) + " " + string(Special);
fillin xx Legislator_Party;

gen pool_has_no_st_leg = _fillin;

count if pool_has_no_st_leg == 1 & Legislator_Party == "D";
local m = r(N);

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_15.tex, text replace;
  noisily display %3.0f `m';
  log close;
};


sum pool_has_no_st_leg if Legislator_Party == "D";
local m = 100 * r(mean);

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_16.tex, text replace;
  noisily display %4.1f `m';
  log close;
};


count if pool_has_no_st_leg == 1 & Legislator_Party == "R";
local m = r(N);

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_17.tex, text replace;
  noisily display %3.0f `m';
  log close;
};


sum pool_has_no_st_leg if Legislator_Party == "R";
local m = 100 * r(mean);

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_18.tex, text replace;
  noisily display %4.1f `m';
  log close;
};


/* STATE LEGISLATORS WHO WIN GENERAL ELECTION IN COMPETITIVE DISTRICTS */

use          ../pools_data/merged_data_33_dems, clear;
append using ../pools_data/merged_data_33_reps;
gen x = 1;
rename Year year;
rename Dist dist;
drop type;
gen type = "G";
replace type = "S" if Special == 1;
keep if Won_General == 1;
save tmp1, replace;

use ../other_data/pres_vote_to_use, clear;
merge m:1 state year dist type using tmp1;
keep if _merge == 3;

gen n_SR = 1 if d_pres_vote_pct < 45.0;
gen n_SD = 1 if d_pres_vote_pct > 55.0;
gen n_C  = 1 if n_SR == . & n_SD == .;
replace n_C = 0 if n_C == .;

count if n_C == 1 & Legislator_Party == "D";
local m = r(N);

quietly {;
  capture log close;
  log using ../output/numbers_for_text/number_21.tex, text replace;
  noisily display %2.0f `m';
  log close;
};


erase tmp0.dta;
erase tmp1.dta;