#delimit ;

set linesize 250;


/* NUMBER OF UNIQUE STATE LEGISLATORS IN OUR SAMPLE */

use          ../pools_data/merged_data_25_dems, clear;
append using ../pools_data/merged_data_25_reps;
sort State Legislator;
count if !(State == State[_n-1] & Legislator == Legislator[_n-1]);


/* NUMBER OF LEGISLATORS WHO ARE IN MORE THAN ONE POOL IN THE SAME YEAR */

use          ../pools_data/merged_data_25_dems, clear;
append using ../pools_data/merged_data_25_reps;
sort State Year Legislator Legislator_Party District;
count if Ideology != .;
local d = r(N);
count if Ideology != . & State == State[_n-1] & Year == Year[_n-1] & Legislator == Legislator[_n-1] & Legislator_Party == Legislator_Party[_n-1];
local n = r(N);
display 100 * `n'/`d';



/* NUMBER OF DISTRICT-YEARS WE HAVE IN OUR SAMPLE AND NUMBER THAT ARE MISSING (DUE TO INABILITY TO MATCH STATE LEG DISTS TO CONG DISTS) */

use          ../pools_data/merged_data_25_dems, clear;
append using ../pools_data/merged_data_25_reps;
rename District dist;
rename Year     year;
rename Ran      ran;
rename Ideology ideology;
rename Legislator_Party party;
drop type;
gen     type = "G" if Special == 0;
replace type = "S" if Special == 1;
merge m:1 state dist year type using ../other_data/cong_incumbency;
gen byte missing_dist = (_merge == 2);
collapse (max) missing_dist, by(state dist year type);
tab missing_dist;



/* DISTRICTS THAT HAVE POOLS WITH STATE LEGISLATORS IN THEM VS. NOT */

use          ../pools_data/merged_data_25_dems, clear;
append using ../pools_data/merged_data_25_reps;
rename District dist;
rename Year     year;
rename Ran      ran;
rename Ideology ideology;
drop type;
gen     type = "G" if Special == 0;
replace type = "S" if Special == 1;
merge m:1 state dist year type using ../other_data/cong_incumbency;
replace inc_D = 0 if inc_D == . & type == "S";
replace inc_R = 0 if inc_R == . & type == "S";
drop if _merge == 2;
drop _merge;
gen n_D = 1 if Legislator_Party == "D";
gen n_R = 1 if Legislator_Party == "R";
gen n_D_run = 1 if Legislator_Party == "D" & ran == 1;
gen n_R_run = 1 if Legislator_Party == "R" & ran == 1;
collapse (sum) n_D n_R n_D_run n_R_run (max) inc_D inc_R, by(state dist year type);
merge m:1 state dist year type using ../other_data/pres_vote_to_use;
drop if _merge == 2;
drop _merge;
gen zero_D = (n_D == 0);
gen zero_R = (n_R == 0);
tab zero_D;
tab zero_R;



/* COMPUTE AVG. WITHIN-STATE STD. DEV. OF IDEOLOGY */

use ../pools_data/merged_data_25_dems, clear;
rename Year     year;
rename Ran      ran;
rename District dist;
rename Ideology ideology;
collapse (sd) sd_ideo_state_D = ideology, by(state year);
sum sd_ideo_state_D;
local sd_state_D = r(mean);

use ../pools_data/merged_data_25_reps, clear;
rename Year     year;
rename Ran      ran;
rename District dist;
rename Ideology ideology;
collapse (sd) sd_ideo_state_R = ideology, by(state year);
sum sd_ideo_state_R;
local sd_state_R = r(mean);



/* COMPUTE AVG. WITHIN-YEAR NATIONAL STD. DEV. OF IDEOLOGY */

use ../pools_data/merged_data_25_dems, clear;
* rename State    state;
rename Year     year;
rename Ran      ran;
rename District dist;
rename Ideology ideology;

sum ideology, detail;
local mean_national_D = r(mean);
local med_national_D = r(p50);
local N_national_D = r(N);

collapse (sd) sd_ideo_national_D = ideology, by(year);
sum sd_ideo_national_D;
local sd_national_D = r(mean);

use ../pools_data/merged_data_25_reps, clear;
* rename State    state;
rename Year     year;
rename Ran      ran;
rename District dist;
rename Ideology ideology;

sum ideology, detail;
local mean_national_R = r(mean);
local med_national_R = r(p50);
local N_national_R = r(N);

collapse (sd) sd_ideo_national_R = ideology, by(year);

sum sd_ideo_national_R;
local sd_national_R = r(mean);



/* COMPARE POOLS TO OVERALL AVERAGES, BY PARTY */

use ../pools_data/merged_data_25_dems, clear;
rename Year     year;
rename Ran      ran;
rename District dist;
rename Ideology ideology;
drop type;
gen     type = "G" if Special == 0;
replace type = "S" if Special == 1;
merge m:1 state dist year type using ../other_data/cong_incumbency;
replace inc_D = 0 if inc_D == . & type == "S";
replace inc_R = 0 if inc_R == . & type == "S";
drop if _merge == 2;
drop _merge;
merge m:1 state dist year type using ../other_data/pres_vote_to_use;
drop if _merge == 2;
gen byte open_seat = (inc_D == 0 & inc_R == 0);
gen byte safe   = (party == "D" &  d_pres_vote_pct > 55.0 & d_pres_vote_pct != .) | (party == "R" & d_pres_vote_pct < 45.0 & d_pres_vote_pct != .);
gen byte compet = (d_pres_vote_pct >= 45.0 & d_pres_vote_pct <= 55.0) if d_pres_vote_pct != .;
replace year = year + 1 if mod(year, 2) == 1;
drop if mod(year, 2) == 1;

/*
egen x = pctile(ideology), p(1);
drop if ideology < x;
drop x;
egen x = pctile(ideology), p(99);
drop if ideology > x;
drop x;
*/

gen ideology_550 = ideology if d_pres_vote_pct > 55.0;
gen ideology_450_550 = ideology if d_pres_vote_pct >= 45.0 & d_pres_vote_pct <= 55.0;
collapse  mean_ideo_pool_D = ideology  mean_ideo_pool_550_D = ideology_550  mean_ideo_pool_450_550_D = ideology_450_550 (sd) sd_ideo_pool_D = ideology (count) n = ideology, by(Unique_ID state dist year);

sum mean_ideo_pool_D, detail;
local N_pool_D = r(N);
local mean_pool_D = r(mean);
local med_pool_D = r(p50);

sum sd_ideo_pool_D, detail;
local sd_pool_D = r(mean);

sum mean_ideo_pool_550_D, detail;
local N_pool_550_D = r(N);
local mean_pool_550_D = r(mean);
local med_pool_550_D = r(p50);

sum mean_ideo_pool_450_550_D, detail;
local N_pool_450_550_D = r(N);
local mean_pool_450_550_D = r(mean);
local med_pool_450_550_D = r(p50);

egen x = max(dist), by(state year);
sum sd_ideo_pool_D if x >= 2, detail;
local sd_pool_D = r(mean);


use ../pools_data/merged_data_25_reps, clear;
rename Year     year;
rename Ran      ran;
rename District dist;
rename Ideology ideology;
drop type;
gen     type = "G" if Special == 0;
replace type = "S" if Special == 1;
merge m:1 state dist year type using ../other_data/cong_incumbency;
replace inc_D = 0 if inc_D == . & type == "S";
replace inc_R = 0 if inc_R == . & type == "S";
drop if _merge == 2;
drop _merge;
merge m:1 state dist year type using ../other_data/pres_vote_to_use;
drop if _merge == 2;
gen byte open_seat = (inc_D == 0 & inc_R == 0);
gen byte safe   = (party == "D" &  d_pres_vote_pct > 55.0 & d_pres_vote_pct != .) | (party == "R" & d_pres_vote_pct < 45.0 & d_pres_vote_pct != .);
gen byte compet = (d_pres_vote_pct >= 45.0 & d_pres_vote_pct <= 55.0) if d_pres_vote_pct != .;

replace year = year + 1 if mod(year, 2) == 1;
drop if mod(year, 2) == 1;

/*
egen x = pctile(ideology), p(1);
drop if ideology < x;
drop x;
egen x = pctile(ideology), p(99);
drop if ideology > x;
drop x;
*/

gen ideology_550 = ideology if 100 - d_pres_vote_pct > 55.0;
gen ideology_450_550 = ideology if d_pres_vote_pct >= 45.0 & d_pres_vote_pct <= 55.0;
collapse  mean_ideo_pool_R = ideology  mean_ideo_pool_550_R = ideology_550  mean_ideo_pool_450_550_R = ideology_450_550 (sd) sd_ideo_pool_R = ideology (count) n = ideology, by(Unique_ID state dist year);

sum mean_ideo_pool_R, detail;
local N_pool_R = r(N);
local mean_pool_R = r(mean);
local med_pool_R = r(p50);

sum sd_ideo_pool_R, detail;
local sd_pool_R = r(mean);

sum mean_ideo_pool_550_R, detail;
local N_pool_550_R = r(N);
local mean_pool_550_R = r(mean);
local med_pool_550_R = r(p50);

sum mean_ideo_pool_450_550_R, detail;
local N_pool_450_550_R = r(N);
local mean_pool_450_550_R = r(mean);
local med_pool_450_550_R = r(p50);




/* AVERAGE ideology OF THE POOLS THAT GENERATED CANDIDATES COMPARED TO THOSE THAT DID NOT */

use ../pools_data/merged_data_25_dems, clear;
rename Year     year;
rename Ran      ran;
rename District dist;
rename Ideology ideology;
drop type;
gen     type = "G" if Special == 0;
replace type = "S" if Special == 1;
merge m:1 state dist year type using ../other_data/cong_incumbency;
drop if _merge == 2;
drop _merge;
merge m:1 state dist year type using ../other_data/pres_vote_to_use;
drop if _merge == 2;
gen byte open_seat = (inc_D == 0 & inc_R == 0);
gen byte safe   = (d_pres_vote_pct >  55.0)                           if d_pres_vote_pct != .;
gen byte compet = (d_pres_vote_pct >= 45.0 & d_pres_vote_pct <= 55.0) if d_pres_vote_pct != .;


replace year = year + 1 if mod(year, 2) == 1;
drop if mod(year, 2) == 1;

/*
egen x = pctile(ideology), p(1);
drop if ideology < x;
drop x;
egen x = pctile(ideology), p(99);
drop if ideology > x;
drop x;
*/

collapse (count) n_D = ideology 
         (mean) mean_ideo_D = ideology  dem_pres_vote = d_pres_vote_pct
         (max) someone_ran_D = ran
 , by(Unique_ID state year);

save tmp1, replace;

use ../pools_data/merged_data_25_reps, clear;
rename Year     year;
rename Ran      ran;
rename District dist;
rename Ideology ideology;
drop type;
gen     type = "G" if Special == 0;
replace type = "S" if Special == 1;
merge m:1 state dist year type using ../other_data/cong_incumbency;
drop if _merge == 2;
drop _merge;
merge m:1 state dist year type using ../other_data/pres_vote_to_use;
drop if _merge == 2;
gen byte open_seat = (inc_D == 0 & inc_R == 0);
gen byte safe   = (d_pres_vote_pct <  45.0)                           if d_pres_vote_pct != .;
gen byte compet = (d_pres_vote_pct >= 45.0 & d_pres_vote_pct <= 55.0) if d_pres_vote_pct != .;

replace year = year + 1 if mod(year, 2) == 1;
drop if mod(year, 2) == 1;

/*
egen x = pctile(ideology), p(1);
drop if ideology < x;
drop x;
egen x = pctile(ideology), p(99);
drop if ideology > x;
drop x;
*/

collapse (count) n_R = ideology 
         (mean) mean_ideo_R = ideology  dem_pres_vote = d_pres_vote_pct
         (max) someone_ran_R = ran
 , by(Unique_ID state year);
merge Unique_ID using tmp1, update;
sort Unique_ID;
save tmp1, replace;


ttest mean_ideo_D, by(someone_ran_D);

ttest mean_ideo_R, by(someone_ran_R);

sum mean_ideo_D if someone_ran_D == 1, detail;
local N_pool_ran1_D = r(N);
local mean_pool_ran1_D = r(mean);
local med_pool_ran1_D = r(p50);

sum mean_ideo_D if someone_ran_D == 0, detail;
local N_pool_ran0_D = r(N);
local mean_pool_ran0_D = r(mean);
local med_pool_ran0_D = r(p50);

sum mean_ideo_R if someone_ran_R == 1, detail;
local N_pool_ran1_R = r(N);
local mean_pool_ran1_R = r(mean);
local med_pool_ran1_R = r(p50);

sum mean_ideo_R if someone_ran_R == 0, detail;
local N_pool_ran0_R = r(N);
local mean_pool_ran0_R = r(mean);
local med_pool_ran0_R = r(p50);




/***************************************************************/
/********** LATEX TABLE OF SUMMARY MEASURES FOR POOLS **********/
/***************************************************************/

quietly {;

  capture log close;
  log using ../output/tables/tbl_summary_stats_25.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf NP-Scores of State Legislators, by Party (Threshold to Define Pools = 25 Percent)} ";
  noisily display "\label{tbl_summary_stats_25} ";
  noisily display "\begin{tabular}{lccrccr} ";
  noisily display "\toprule\toprule ";
  noisily display "& \multicolumn{3}{c}{Democrats} & \multicolumn{3}{c}{~Republicans} \\ [.05in] "; 
  noisily display "            & Mean       & Median     &           & ~Mean       & Median     &           \\ ";
  noisily display "Item        & NP-Score   & NP-Score   & \# Legs.  & ~NP-Score   & NP-Score   & \# Legs.  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "National Average/Median     & " %4.2f `mean_national_D'     " & " %4.2f `med_national_D'     " & " %6.0fc `N_national_D'     " & ~" %4.2f `mean_national_R'     " & " %4.2f `med_national_R'     " & " %6.0fc `N_national_R'     " \\ [.01in] "; 
  noisily display "\midrule ";
  noisily display "            &    &    & \# Pools  &    &    & \# Pools  \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "All Pools                   & " %4.2f `mean_pool_D'         " & " %4.2f `med_pool_D'         " & " %6.0fc `N_pool_D'         " & ~" %4.2f `mean_pool_R'         " & " %4.2f `med_pool_R'         " & " %6.0fc `N_pool_R'         " \\ [.01in] "; 
  noisily display "Pools in Safe Districts     & " %4.2f `mean_pool_550_D'     " & " %4.2f `med_pool_550_D'     " & " %6.0fc `N_pool_550_D'     " & ~" %4.2f `mean_pool_550_R'     " & " %4.2f `med_pool_550_R'     " & " %6.0fc `N_pool_550_R'     " \\ [.01in] "; 
  noisily display "Pools in Competitive Dists  & " %4.2f `mean_pool_450_550_D' " & " %4.2f `med_pool_450_550_D' " & " %6.0fc `N_pool_450_550_D' " & ~" %4.2f `mean_pool_450_550_R' " & " %4.2f `med_pool_450_550_R' " & " %6.0fc `N_pool_450_550_R' " \\ [.01in] "; 
  noisily display "Pools With 1+ Cong Cand     & " %4.2f `mean_pool_ran1_D'    " & " %4.2f `med_pool_ran1_D'    " & " %6.0fc `N_pool_ran1_D'    " & ~" %4.2f `mean_pool_ran1_R'    " & " %4.2f `med_pool_ran1_R'    " & " %6.0fc `N_pool_ran1_R'    " \\ [.01in] "; 
  noisily display "Pools With 0 Cong Cands     & " %4.2f `mean_pool_ran0_D'    " & " %4.2f `med_pool_ran0_D'    " & " %6.0fc `N_pool_ran0_D'    " & ~" %4.2f `mean_pool_ran0_R'    " & " %4.2f `med_pool_ran0_R'    " & " %6.0fc `N_pool_ran0_R'    " \\ [.01in] "; 
  noisily display "\midrule ";
  noisily display "National Std. Dev.          & " %4.2f `sd_national_D'       " & & "                           " & ~" %4.2f `sd_national_R'       " & & "                           " \\ [.01in] "; 
  noisily display "Avg. Within-State Std. Dev. & " %4.2f `sd_state_D'          " & & "                           " & ~" %4.2f `sd_state_R'          " & & "                           " \\ [.01in] "; 
  noisily display "Avg. Within-Pool Std. Dev.  & " %4.2f `sd_pool_D'           " & & "                           " & ~" %4.2f `sd_pool_R'           " & & "                           " \\ [.01in] "; 
  noisily display "\bottomrule ";
  noisily display "\multicolumn{7}{p{.9\textwidth}}{In the first row the unit of observation is the individual legislator.  In rows 2-6 the unit of observation is the pool.}";
  noisily display "\end{tabular} ";
  noisily display "\end{table} ";

  log close;

};



erase tmp1.dta;
